/*
 * Copyright (c) Microsoft Corporation. All rights reserved.
 * Licensed under the MIT License. See License.txt in the project root for license information.
 *
 * Code generated by Microsoft (R) AutoRest Code Generator.
 * Changes may cause incorrect behavior and will be lost if the code is regenerated.
 */

import { BaseResource, CloudError } from "ms-rest-azure";
import * as moment from "moment";

export {

  BaseResource,
  CloudError
};

/**
 * Describes the properties of a Compute Operation value.
 */
export interface ComputeOperationValue {
  /**
   * The origin of the compute operation.
   */
  readonly origin?: string;
  /**
   * The name of the compute operation.
   */
  readonly name?: string;
  /**
   * The display name of the compute operation.
   */
  readonly operation?: string;
  /**
   * The display name of the resource the operation applies to.
   */
  readonly resource?: string;
  /**
   * The description of the operation.
   */
  readonly description?: string;
  /**
   * The resource provider for the operation.
   */
  readonly provider?: string;
}

/**
 * Instance view status.
 */
export interface InstanceViewStatus {
  /**
   * The status code.
   */
  code?: string;
  /**
   * The level code. Possible values include: 'Info', 'Warning', 'Error'
   */
  level?: string;
  /**
   * The short localizable label for the status.
   */
  displayStatus?: string;
  /**
   * The detailed status message, including for alerts and error messages.
   */
  message?: string;
  /**
   * The time of the status.
   */
  time?: Date;
}

export interface SubResource extends BaseResource {
  /**
   * Resource Id
  */
  id?: string;
}

/**
 * Describes a virtual machine scale set sku.
*/
export interface Sku {
  /**
   * The sku name.
  */
  name?: string;
  /**
   * Specifies the tier of virtual machines in a scale set.<br /><br /> Possible Values:<br /><br
   * /> **Standard**<br /><br /> **Basic**
  */
  tier?: string;
  /**
   * Specifies the number of virtual machines in the scale set.
  */
  capacity?: number;
}

/**
 * The Resource model definition.
*/
export interface Resource extends BaseResource {
  /**
   * Resource Id
  */
  readonly id?: string;
  /**
   * Resource name
  */
  readonly name?: string;
  /**
   * Resource type
  */
  readonly type?: string;
  /**
   * Resource location
  */
  location: string;
  /**
   * Resource tags
  */
  tags?: { [propertyName: string]: string };
}

/**
 * Specifies information about the availability set that the virtual machine should be assigned to.
 * Virtual machines specified in the same availability set are allocated to different nodes to
 * maximize availability. For more information about availability sets, see [Manage the
 * availability of virtual
 * machines](https://docs.microsoft.com/azure/virtual-machines/virtual-machines-windows-manage-availability?toc=%2fazure%2fvirtual-machines%2fwindows%2ftoc.json).
 * <br><br> For more information on Azure planned maintenance, see [Planned maintenance for virtual
 * machines in
 * Azure](https://docs.microsoft.com/azure/virtual-machines/virtual-machines-windows-planned-maintenance?toc=%2fazure%2fvirtual-machines%2fwindows%2ftoc.json)
 * <br><br> Currently, a VM can only be added to availability set at creation time. An existing VM
 * cannot be added to an availability set.
*/
export interface AvailabilitySet extends Resource {
  /**
   * Update Domain count.
  */
  platformUpdateDomainCount?: number;
  /**
   * Fault Domain count.
  */
  platformFaultDomainCount?: number;
  /**
   * A list of references to all virtual machines in the availability set.
  */
  virtualMachines?: SubResource[];
  /**
   * The resource status information.
  */
  readonly statuses?: InstanceViewStatus[];
  /**
   * Sku of the availability set, only name is required to be set. See AvailabilitySetSkuTypes for
   * possible set of values. Use 'Aligned' for virtual machines with managed disks and 'Classic'
   * for virtual machines with unmanaged disks. Default value is 'Classic'.
  */
  sku?: Sku;
}

/**
 * The Update Resource model definition.
*/
export interface UpdateResource extends BaseResource {
  /**
   * Resource tags
  */
  tags?: { [propertyName: string]: string };
}

/**
 * Specifies information about the availability set that the virtual machine should be assigned to.
 * Only tags may be updated.
*/
export interface AvailabilitySetUpdate extends UpdateResource {
  /**
   * Update Domain count.
  */
  platformUpdateDomainCount?: number;
  /**
   * Fault Domain count.
  */
  platformFaultDomainCount?: number;
  /**
   * A list of references to all virtual machines in the availability set.
  */
  virtualMachines?: SubResource[];
  /**
   * The resource status information.
  */
  readonly statuses?: InstanceViewStatus[];
  /**
   * Sku of the availability set
  */
  sku?: Sku;
}

/**
 * Describes the properties of a VM size.
*/
export interface VirtualMachineSize {
  /**
   * The name of the virtual machine size.
  */
  name?: string;
  /**
   * The number of cores supported by the virtual machine size.
  */
  numberOfCores?: number;
  /**
   * The OS disk size, in MB, allowed by the virtual machine size.
  */
  osDiskSizeInMB?: number;
  /**
   * The resource disk size, in MB, allowed by the virtual machine size.
  */
  resourceDiskSizeInMB?: number;
  /**
   * The amount of memory, in MB, supported by the virtual machine size.
  */
  memoryInMB?: number;
  /**
   * The maximum number of data disks that can be attached to the virtual machine size.
  */
  maxDataDiskCount?: number;
}

/**
 * Describes a Virtual Machine Extension Image.
*/
export interface VirtualMachineExtensionImage extends Resource {
  /**
   * The operating system this extension supports.
  */
  operatingSystem: string;
  /**
   * The type of role (IaaS or PaaS) this extension supports.
  */
  computeRole: string;
  /**
   * The schema defined by publisher, where extension consumers should provide settings in a
   * matching schema.
  */
  handlerSchema: string;
  /**
   * Whether the extension can be used on xRP VMScaleSets. By default existing extensions are
   * usable on scalesets, but there might be cases where a publisher wants to explicitly indicate
   * the extension is only enabled for CRP VMs but not VMSS.
  */
  vmScaleSetEnabled?: boolean;
  /**
   * Whether the handler can support multiple extensions.
  */
  supportsMultipleExtensions?: boolean;
}

/**
 * Virtual machine image resource information.
*/
export interface VirtualMachineImageResource extends SubResource {
  /**
   * The name of the resource.
  */
  name: string;
  /**
   * The supported Azure location of the resource.
  */
  location: string;
  /**
   * Specifies the tags that are assigned to the virtual machine. For more information about using
   * tags, see [Using tags to organize your Azure
   * resources](https://docs.microsoft.com/azure/azure-resource-manager/resource-group-using-tags.md).
  */
  tags?: { [propertyName: string]: string };
}

/**
 * The instance view of a virtual machine extension.
*/
export interface VirtualMachineExtensionInstanceView {
  /**
   * The virtual machine extension name.
  */
  name?: string;
  /**
   * Specifies the type of the extension; an example is "CustomScriptExtension".
  */
  type?: string;
  /**
   * Specifies the version of the script handler.
  */
  typeHandlerVersion?: string;
  /**
   * The resource status information.
  */
  substatuses?: InstanceViewStatus[];
  /**
   * The resource status information.
  */
  statuses?: InstanceViewStatus[];
}

/**
 * Describes a Virtual Machine Extension.
*/
export interface VirtualMachineExtension extends Resource {
  /**
   * How the extension handler should be forced to update even if the extension configuration has
   * not changed.
  */
  forceUpdateTag?: string;
  /**
   * The name of the extension handler publisher.
  */
  publisher?: string;
  /**
   * Specifies the type of the extension; an example is "CustomScriptExtension".
  */
  virtualMachineExtensionType?: string;
  /**
   * Specifies the version of the script handler.
  */
  typeHandlerVersion?: string;
  /**
   * Indicates whether the extension should use a newer minor version if one is available at
   * deployment time. Once deployed, however, the extension will not upgrade minor versions unless
   * redeployed, even with this property set to true.
  */
  autoUpgradeMinorVersion?: boolean;
  /**
   * Json formatted public settings for the extension.
  */
  settings?: any;
  /**
   * The extension can contain either protectedSettings or protectedSettingsFromKeyVault or no
   * protected settings at all.
  */
  protectedSettings?: any;
  /**
   * The provisioning state, which only appears in the response.
  */
  readonly provisioningState?: string;
  /**
   * The virtual machine extension instance view.
  */
  instanceView?: VirtualMachineExtensionInstanceView;
}

/**
 * Describes a Virtual Machine Extension.
*/
export interface VirtualMachineExtensionUpdate extends UpdateResource {
  /**
   * How the extension handler should be forced to update even if the extension configuration has
   * not changed.
  */
  forceUpdateTag?: string;
  /**
   * The name of the extension handler publisher.
  */
  publisher?: string;
  /**
   * Specifies the type of the extension; an example is "CustomScriptExtension".
  */
  type?: string;
  /**
   * Specifies the version of the script handler.
  */
  typeHandlerVersion?: string;
  /**
   * Indicates whether the extension should use a newer minor version if one is available at
   * deployment time. Once deployed, however, the extension will not upgrade minor versions unless
   * redeployed, even with this property set to true.
  */
  autoUpgradeMinorVersion?: boolean;
  /**
   * Json formatted public settings for the extension.
  */
  settings?: any;
  /**
   * The extension can contain either protectedSettings or protectedSettingsFromKeyVault or no
   * protected settings at all.
  */
  protectedSettings?: any;
}

/**
 * The List Extension operation response
*/
export interface VirtualMachineExtensionsListResult {
  /**
   * The list of extensions
  */
  value?: VirtualMachineExtension[];
}

/**
 * Used for establishing the purchase context of any 3rd Party artifact through MarketPlace.
*/
export interface PurchasePlan {
  /**
   * The publisher ID.
  */
  publisher: string;
  /**
   * The plan ID.
  */
  name: string;
  /**
   * Specifies the product of the image from the marketplace. This is the same value as Offer under
   * the imageReference element.
  */
  product: string;
}

/**
 * Contains the os disk image information.
*/
export interface OSDiskImage {
  /**
   * The operating system of the osDiskImage. Possible values include: 'Windows', 'Linux'
  */
  operatingSystem: string;
}

/**
 * Contains the data disk images information.
*/
export interface DataDiskImage {
  /**
   * Specifies the logical unit number of the data disk. This value is used to identify data disks
   * within the VM and therefore must be unique for each data disk attached to a VM.
  */
  readonly lun?: number;
}

/**
 * Describes automatic OS upgrade properties on the image.
*/
export interface AutomaticOSUpgradeProperties {
  /**
   * Specifies whether automatic OS upgrade is supported on the image.
  */
  automaticOSUpgradeSupported: boolean;
}

/**
 * Describes a Virtual Machine Image.
*/
export interface VirtualMachineImage extends VirtualMachineImageResource {
  plan?: PurchasePlan;
  osDiskImage?: OSDiskImage;
  dataDiskImages?: DataDiskImage[];
  automaticOSUpgradeProperties?: AutomaticOSUpgradeProperties;
}

/**
 * The Usage Names.
*/
export interface UsageName {
  /**
   * The name of the resource.
  */
  value?: string;
  /**
   * The localized name of the resource.
  */
  localizedValue?: string;
}

/**
 * Describes Compute Resource Usage.
*/
export interface Usage {
  /**
   * The current usage of the resource.
  */
  currentValue: number;
  /**
   * The maximum permitted usage of the resource.
  */
  limit: number;
  /**
   * The name of the type of usage.
  */
  name: UsageName;
}

/**
 * Parameters for Reimaging Virtual Machine. NOTE: Virtual Machine OS disk will always be reimaged
*/
export interface VirtualMachineReimageParameters {
  /**
   * Specifies whether to reimage temp disk. Default value: false.
  */
  tempDisk?: boolean;
}

/**
 * Capture Virtual Machine parameters.
*/
export interface VirtualMachineCaptureParameters {
  /**
   * The captured virtual hard disk's name prefix.
  */
  vhdPrefix: string;
  /**
   * The destination container name.
  */
  destinationContainerName: string;
  /**
   * Specifies whether to overwrite the destination virtual hard disk, in case of conflict.
  */
  overwriteVhds: boolean;
}

/**
 * Output of virtual machine capture operation.
*/
export interface VirtualMachineCaptureResult extends SubResource {
  /**
   * the schema of the captured virtual machine
  */
  readonly schema?: string;
  /**
   * the version of the content
  */
  readonly contentVersion?: string;
  /**
   * parameters of the captured virtual machine
  */
  readonly parameters?: any;
  /**
   * a list of resource items of the captured virtual machine
  */
  readonly resources?: any[];
}

/**
 * Specifies information about the marketplace image used to create the virtual machine. This
 * element is only used for marketplace images. Before you can use a marketplace image from an API,
 * you must enable the image for programmatic use.  In the Azure portal, find the marketplace image
 * that you want to use and then click **Want to deploy programmatically, Get Started ->**. Enter
 * any required information and then click **Save**.
*/
export interface Plan {
  /**
   * The plan ID.
  */
  name?: string;
  /**
   * The publisher ID.
  */
  publisher?: string;
  /**
   * Specifies the product of the image from the marketplace. This is the same value as Offer under
   * the imageReference element.
  */
  product?: string;
  /**
   * The promotion code.
  */
  promotionCode?: string;
}

/**
 * Specifies the hardware settings for the virtual machine.
*/
export interface HardwareProfile {
  /**
   * Specifies the size of the virtual machine. For more information about virtual machine sizes,
   * see [Sizes for virtual
   * machines](https://docs.microsoft.com/azure/virtual-machines/virtual-machines-windows-sizes?toc=%2fazure%2fvirtual-machines%2fwindows%2ftoc.json).
   * <br><br> The available VM sizes depend on region and availability set. For a list of available
   * sizes use these APIs:  <br><br> [List all available virtual machine sizes in an availability
   * set](https://docs.microsoft.com/rest/api/compute/availabilitysets/listavailablesizes) <br><br>
   * [List all available virtual machine sizes in a
   * region](https://docs.microsoft.com/rest/api/compute/virtualmachinesizes/list) <br><br> [List
   * all available virtual machine sizes for
   * resizing](https://docs.microsoft.com/rest/api/compute/virtualmachines/listavailablesizes).
   * Possible values include: 'Basic_A0', 'Basic_A1', 'Basic_A2', 'Basic_A3', 'Basic_A4',
   * 'Standard_A0', 'Standard_A1', 'Standard_A2', 'Standard_A3', 'Standard_A4', 'Standard_A5',
   * 'Standard_A6', 'Standard_A7', 'Standard_A8', 'Standard_A9', 'Standard_A10', 'Standard_A11',
   * 'Standard_A1_v2', 'Standard_A2_v2', 'Standard_A4_v2', 'Standard_A8_v2', 'Standard_A2m_v2',
   * 'Standard_A4m_v2', 'Standard_A8m_v2', 'Standard_B1s', 'Standard_B1ms', 'Standard_B2s',
   * 'Standard_B2ms', 'Standard_B4ms', 'Standard_B8ms', 'Standard_D1', 'Standard_D2',
   * 'Standard_D3', 'Standard_D4', 'Standard_D11', 'Standard_D12', 'Standard_D13', 'Standard_D14',
   * 'Standard_D1_v2', 'Standard_D2_v2', 'Standard_D3_v2', 'Standard_D4_v2', 'Standard_D5_v2',
   * 'Standard_D2_v3', 'Standard_D4_v3', 'Standard_D8_v3', 'Standard_D16_v3', 'Standard_D32_v3',
   * 'Standard_D64_v3', 'Standard_D2s_v3', 'Standard_D4s_v3', 'Standard_D8s_v3',
   * 'Standard_D16s_v3', 'Standard_D32s_v3', 'Standard_D64s_v3', 'Standard_D11_v2',
   * 'Standard_D12_v2', 'Standard_D13_v2', 'Standard_D14_v2', 'Standard_D15_v2', 'Standard_DS1',
   * 'Standard_DS2', 'Standard_DS3', 'Standard_DS4', 'Standard_DS11', 'Standard_DS12',
   * 'Standard_DS13', 'Standard_DS14', 'Standard_DS1_v2', 'Standard_DS2_v2', 'Standard_DS3_v2',
   * 'Standard_DS4_v2', 'Standard_DS5_v2', 'Standard_DS11_v2', 'Standard_DS12_v2',
   * 'Standard_DS13_v2', 'Standard_DS14_v2', 'Standard_DS15_v2', 'Standard_DS13-4_v2',
   * 'Standard_DS13-2_v2', 'Standard_DS14-8_v2', 'Standard_DS14-4_v2', 'Standard_E2_v3',
   * 'Standard_E4_v3', 'Standard_E8_v3', 'Standard_E16_v3', 'Standard_E32_v3', 'Standard_E64_v3',
   * 'Standard_E2s_v3', 'Standard_E4s_v3', 'Standard_E8s_v3', 'Standard_E16s_v3',
   * 'Standard_E32s_v3', 'Standard_E64s_v3', 'Standard_E32-16_v3', 'Standard_E32-8s_v3',
   * 'Standard_E64-32s_v3', 'Standard_E64-16s_v3', 'Standard_F1', 'Standard_F2', 'Standard_F4',
   * 'Standard_F8', 'Standard_F16', 'Standard_F1s', 'Standard_F2s', 'Standard_F4s', 'Standard_F8s',
   * 'Standard_F16s', 'Standard_F2s_v2', 'Standard_F4s_v2', 'Standard_F8s_v2', 'Standard_F16s_v2',
   * 'Standard_F32s_v2', 'Standard_F64s_v2', 'Standard_F72s_v2', 'Standard_G1', 'Standard_G2',
   * 'Standard_G3', 'Standard_G4', 'Standard_G5', 'Standard_GS1', 'Standard_GS2', 'Standard_GS3',
   * 'Standard_GS4', 'Standard_GS5', 'Standard_GS4-8', 'Standard_GS4-4', 'Standard_GS5-16',
   * 'Standard_GS5-8', 'Standard_H8', 'Standard_H16', 'Standard_H8m', 'Standard_H16m',
   * 'Standard_H16r', 'Standard_H16mr', 'Standard_L4s', 'Standard_L8s', 'Standard_L16s',
   * 'Standard_L32s', 'Standard_M64s', 'Standard_M64ms', 'Standard_M128s', 'Standard_M128ms',
   * 'Standard_M64-32ms', 'Standard_M64-16ms', 'Standard_M128-64ms', 'Standard_M128-32ms',
   * 'Standard_NC6', 'Standard_NC12', 'Standard_NC24', 'Standard_NC24r', 'Standard_NC6s_v2',
   * 'Standard_NC12s_v2', 'Standard_NC24s_v2', 'Standard_NC24rs_v2', 'Standard_NC6s_v3',
   * 'Standard_NC12s_v3', 'Standard_NC24s_v3', 'Standard_NC24rs_v3', 'Standard_ND6s',
   * 'Standard_ND12s', 'Standard_ND24s', 'Standard_ND24rs', 'Standard_NV6', 'Standard_NV12',
   * 'Standard_NV24'
  */
  vmSize?: string;
}

/**
 * Specifies information about the image to use. You can specify information about platform images,
 * marketplace images, or virtual machine images. This element is required when you want to use a
 * platform image, marketplace image, or virtual machine image, but is not used in other creation
 * operations.
*/
export interface ImageReference extends SubResource {
  /**
   * The image publisher.
  */
  publisher?: string;
  /**
   * Specifies the offer of the platform image or marketplace image used to create the virtual
   * machine.
  */
  offer?: string;
  /**
   * The image SKU.
  */
  sku?: string;
  /**
   * Specifies the version of the platform image or marketplace image used to create the virtual
   * machine. The allowed formats are Major.Minor.Build or 'latest'. Major, Minor, and Build are
   * decimal numbers. Specify 'latest' to use the latest version of an image available at deploy
   * time. Even if you use 'latest', the VM image will not automatically update after deploy time
   * even if a new version becomes available.
  */
  version?: string;
}

/**
 * Describes a reference to Key Vault Secret
*/
export interface KeyVaultSecretReference {
  /**
   * The URL referencing a secret in a Key Vault.
  */
  secretUrl: string;
  /**
   * The relative URL of the Key Vault containing the secret.
  */
  sourceVault: SubResource;
}

/**
 * Describes a reference to Key Vault Key
*/
export interface KeyVaultKeyReference {
  /**
   * The URL referencing a key encryption key in Key Vault.
  */
  keyUrl: string;
  /**
   * The relative URL of the Key Vault containing the key.
  */
  sourceVault: SubResource;
}

/**
 * Describes a Encryption Settings for a Disk
*/
export interface DiskEncryptionSettings {
  /**
   * Specifies the location of the disk encryption key, which is a Key Vault Secret.
  */
  diskEncryptionKey?: KeyVaultSecretReference;
  /**
   * Specifies the location of the key encryption key in Key Vault.
  */
  keyEncryptionKey?: KeyVaultKeyReference;
  /**
   * Specifies whether disk encryption should be enabled on the virtual machine.
  */
  enabled?: boolean;
}

/**
 * Describes the uri of a disk.
*/
export interface VirtualHardDisk {
  /**
   * Specifies the virtual hard disk's uri.
  */
  uri?: string;
}

/**
 * Describes the parameters of ephemeral disk settings that can be specified for operating system
 * disk. <br><br> NOTE: The ephemeral disk settings can only be specified for managed disk.
*/
export interface DiffDiskSettings {
  /**
   * Specifies the ephemeral disk settings for operating system disk. Possible values include:
   * 'Local'
  */
  option?: string;
}

/**
 * The parameters of a managed disk.
*/
export interface ManagedDiskParameters extends SubResource {
  /**
   * Specifies the storage account type for the managed disk. NOTE: UltraSSD_LRS can only be used
   * with data disks, it cannot be used with OS Disk. Possible values include: 'Standard_LRS',
   * 'Premium_LRS', 'StandardSSD_LRS', 'UltraSSD_LRS'
  */
  storageAccountType?: string;
}

/**
 * Specifies information about the operating system disk used by the virtual machine. <br><br> For
 * more information about disks, see [About disks and VHDs for Azure virtual
 * machines](https://docs.microsoft.com/azure/virtual-machines/virtual-machines-windows-about-disks-vhds?toc=%2fazure%2fvirtual-machines%2fwindows%2ftoc.json).
*/
export interface OSDisk {
  /**
   * This property allows you to specify the type of the OS that is included in the disk if
   * creating a VM from user-image or a specialized VHD. <br><br> Possible values are: <br><br>
   * **Windows** <br><br> **Linux**. Possible values include: 'Windows', 'Linux'
  */
  osType?: string;
  /**
   * Specifies the encryption settings for the OS Disk. <br><br> Minimum api-version: 2015-06-15
  */
  encryptionSettings?: DiskEncryptionSettings;
  /**
   * The disk name.
  */
  name?: string;
  /**
   * The virtual hard disk.
  */
  vhd?: VirtualHardDisk;
  /**
   * The source user image virtual hard disk. The virtual hard disk will be copied before being
   * attached to the virtual machine. If SourceImage is provided, the destination virtual hard
   * drive must not exist.
  */
  image?: VirtualHardDisk;
  /**
   * Specifies the caching requirements. <br><br> Possible values are: <br><br> **None** <br><br>
   * **ReadOnly** <br><br> **ReadWrite** <br><br> Default: **None for Standard storage. ReadOnly
   * for Premium storage**. Possible values include: 'None', 'ReadOnly', 'ReadWrite'
  */
  caching?: string;
  /**
   * Specifies whether writeAccelerator should be enabled or disabled on the disk.
  */
  writeAcceleratorEnabled?: boolean;
  /**
   * Specifies the ephemeral Disk Settings for the operating system disk used by the virtual
   * machine.
  */
  diffDiskSettings?: DiffDiskSettings;
  /**
   * Specifies how the virtual machine should be created.<br><br> Possible values are:<br><br>
   * **Attach** \u2013 This value is used when you are using a specialized disk to create the
   * virtual machine.<br><br> **FromImage** \u2013 This value is used when you are using an image
   * to create the virtual machine. If you are using a platform image, you also use the
   * imageReference element described above. If you are using a marketplace image, you  also use
   * the plan element previously described. Possible values include: 'FromImage', 'Empty', 'Attach'
  */
  createOption: string;
  /**
   * Specifies the size of an empty data disk in gigabytes. This element can be used to overwrite
   * the size of the disk in a virtual machine image. <br><br> This value cannot be larger than
   * 1023 GB
  */
  diskSizeGB?: number;
  /**
   * The managed disk parameters.
  */
  managedDisk?: ManagedDiskParameters;
}

/**
 * Describes a data disk.
*/
export interface DataDisk {
  /**
   * Specifies the logical unit number of the data disk. This value is used to identify data disks
   * within the VM and therefore must be unique for each data disk attached to a VM.
  */
  lun: number;
  /**
   * The disk name.
  */
  name?: string;
  /**
   * The virtual hard disk.
  */
  vhd?: VirtualHardDisk;
  /**
   * The source user image virtual hard disk. The virtual hard disk will be copied before being
   * attached to the virtual machine. If SourceImage is provided, the destination virtual hard
   * drive must not exist.
  */
  image?: VirtualHardDisk;
  /**
   * Specifies the caching requirements. <br><br> Possible values are: <br><br> **None** <br><br>
   * **ReadOnly** <br><br> **ReadWrite** <br><br> Default: **None for Standard storage. ReadOnly
   * for Premium storage**. Possible values include: 'None', 'ReadOnly', 'ReadWrite'
  */
  caching?: string;
  /**
   * Specifies whether writeAccelerator should be enabled or disabled on the disk.
  */
  writeAcceleratorEnabled?: boolean;
  /**
   * Specifies how the virtual machine should be created.<br><br> Possible values are:<br><br>
   * **Attach** \u2013 This value is used when you are using a specialized disk to create the
   * virtual machine.<br><br> **FromImage** \u2013 This value is used when you are using an image
   * to create the virtual machine. If you are using a platform image, you also use the
   * imageReference element described above. If you are using a marketplace image, you  also use
   * the plan element previously described. Possible values include: 'FromImage', 'Empty', 'Attach'
  */
  createOption: string;
  /**
   * Specifies the size of an empty data disk in gigabytes. This element can be used to overwrite
   * the size of the disk in a virtual machine image. <br><br> This value cannot be larger than
   * 1023 GB
  */
  diskSizeGB?: number;
  /**
   * The managed disk parameters.
  */
  managedDisk?: ManagedDiskParameters;
}

/**
 * Specifies the storage settings for the virtual machine disks.
*/
export interface StorageProfile {
  /**
   * Specifies information about the image to use. You can specify information about platform
   * images, marketplace images, or virtual machine images. This element is required when you want
   * to use a platform image, marketplace image, or virtual machine image, but is not used in other
   * creation operations.
  */
  imageReference?: ImageReference;
  /**
   * Specifies information about the operating system disk used by the virtual machine. <br><br>
   * For more information about disks, see [About disks and VHDs for Azure virtual
   * machines](https://docs.microsoft.com/azure/virtual-machines/virtual-machines-windows-about-disks-vhds?toc=%2fazure%2fvirtual-machines%2fwindows%2ftoc.json).
  */
  osDisk?: OSDisk;
  /**
   * Specifies the parameters that are used to add a data disk to a virtual machine. <br><br> For
   * more information about disks, see [About disks and VHDs for Azure virtual
   * machines](https://docs.microsoft.com/azure/virtual-machines/virtual-machines-windows-about-disks-vhds?toc=%2fazure%2fvirtual-machines%2fwindows%2ftoc.json).
  */
  dataDisks?: DataDisk[];
}

/**
 * Enables or disables a capability on the virtual machine or virtual machine scale set.
*/
export interface AdditionalCapabilities {
  /**
   * The flag that enables or disables a capability to have one or more managed data disks with
   * UltraSSD_LRS storage account type on the VM or VMSS. Managed disks with storage account type
   * UltraSSD_LRS can be added to a virtual machine or virtual machine scale set only if this
   * property is enabled.
  */
  ultraSSDEnabled?: boolean;
}

/**
 * Specifies additional XML formatted information that can be included in the Unattend.xml file,
 * which is used by Windows Setup. Contents are defined by setting name, component name, and the
 * pass in which the content is applied.
*/
export interface AdditionalUnattendContent {
  /**
   * The pass name. Currently, the only allowable value is OobeSystem. Possible values include:
   * 'OobeSystem'
  */
  passName?: string;
  /**
   * The component name. Currently, the only allowable value is Microsoft-Windows-Shell-Setup.
   * Possible values include: 'Microsoft-Windows-Shell-Setup'
  */
  componentName?: string;
  /**
   * Specifies the name of the setting to which the content applies. Possible values are:
   * FirstLogonCommands and AutoLogon. Possible values include: 'AutoLogon', 'FirstLogonCommands'
  */
  settingName?: string;
  /**
   * Specifies the XML formatted content that is added to the unattend.xml file for the specified
   * path and component. The XML must be less than 4KB and must include the root element for the
   * setting or feature that is being inserted.
  */
  content?: string;
}

/**
 * Describes Protocol and thumbprint of Windows Remote Management listener
*/
export interface WinRMListener {
  /**
   * Specifies the protocol of listener. <br><br> Possible values are: <br>**http** <br><br>
   * **https**. Possible values include: 'Http', 'Https'
  */
  protocol?: string;
  /**
   * This is the URL of a certificate that has been uploaded to Key Vault as a secret. For adding a
   * secret to the Key Vault, see [Add a key or secret to the key
   * vault](https://docs.microsoft.com/azure/key-vault/key-vault-get-started/#add). In this case,
   * your certificate needs to be It is the Base64 encoding of the following JSON Object which is
   * encoded in UTF-8: <br><br> {<br>  "data":"<Base64-encoded-certificate>",<br>
   * "dataType":"pfx",<br>  "password":"<pfx-file-password>"<br>}
  */
  certificateUrl?: string;
}

/**
 * Describes Windows Remote Management configuration of the VM
*/
export interface WinRMConfiguration {
  /**
   * The list of Windows Remote Management listeners
  */
  listeners?: WinRMListener[];
}

/**
 * Specifies Windows operating system settings on the virtual machine.
*/
export interface WindowsConfiguration {
  /**
   * Indicates whether virtual machine agent should be provisioned on the virtual machine. <br><br>
   * When this property is not specified in the request body, default behavior is to set it to
   * true.  This will ensure that VM Agent is installed on the VM so that extensions can be added
   * to the VM later.
  */
  provisionVMAgent?: boolean;
  /**
   * Indicates whether virtual machine is enabled for automatic updates.
  */
  enableAutomaticUpdates?: boolean;
  /**
   * Specifies the time zone of the virtual machine. e.g. "Pacific Standard Time"
  */
  timeZone?: string;
  /**
   * Specifies additional base-64 encoded XML formatted information that can be included in the
   * Unattend.xml file, which is used by Windows Setup.
  */
  additionalUnattendContent?: AdditionalUnattendContent[];
  /**
   * Specifies the Windows Remote Management listeners. This enables remote Windows PowerShell.
  */
  winRM?: WinRMConfiguration;
}

/**
 * Contains information about SSH certificate public key and the path on the Linux VM where the
 * public key is placed.
*/
export interface SshPublicKey {
  /**
   * Specifies the full path on the created VM where ssh public key is stored. If the file already
   * exists, the specified key is appended to the file. Example: /home/user/.ssh/authorized_keys
  */
  path?: string;
  /**
   * SSH public key certificate used to authenticate with the VM through ssh. The key needs to be
   * at least 2048-bit and in ssh-rsa format. <br><br> For creating ssh keys, see [Create SSH keys
   * on Linux and Mac for Linux VMs in
   * Azure](https://docs.microsoft.com/azure/virtual-machines/virtual-machines-linux-mac-create-ssh-keys?toc=%2fazure%2fvirtual-machines%2flinux%2ftoc.json).
  */
  keyData?: string;
}

/**
 * SSH configuration for Linux based VMs running on Azure
*/
export interface SshConfiguration {
  /**
   * The list of SSH public keys used to authenticate with linux based VMs.
  */
  publicKeys?: SshPublicKey[];
}

/**
 * Specifies the Linux operating system settings on the virtual machine. <br><br>For a list of
 * supported Linux distributions, see [Linux on Azure-Endorsed
 * Distributions](https://docs.microsoft.com/azure/virtual-machines/virtual-machines-linux-endorsed-distros?toc=%2fazure%2fvirtual-machines%2flinux%2ftoc.json)
 * <br><br> For running non-endorsed distributions, see [Information for Non-Endorsed
 * Distributions](https://docs.microsoft.com/azure/virtual-machines/virtual-machines-linux-create-upload-generic?toc=%2fazure%2fvirtual-machines%2flinux%2ftoc.json).
*/
export interface LinuxConfiguration {
  /**
   * Specifies whether password authentication should be disabled.
  */
  disablePasswordAuthentication?: boolean;
  /**
   * Specifies the ssh key configuration for a Linux OS.
  */
  ssh?: SshConfiguration;
  /**
   * Indicates whether virtual machine agent should be provisioned on the virtual machine. <br><br>
   * When this property is not specified in the request body, default behavior is to set it to
   * true.  This will ensure that VM Agent is installed on the VM so that extensions can be added
   * to the VM later.
  */
  provisionVMAgent?: boolean;
}

/**
 * Describes a single certificate reference in a Key Vault, and where the certificate should reside
 * on the VM.
*/
export interface VaultCertificate {
  /**
   * This is the URL of a certificate that has been uploaded to Key Vault as a secret. For adding a
   * secret to the Key Vault, see [Add a key or secret to the key
   * vault](https://docs.microsoft.com/azure/key-vault/key-vault-get-started/#add). In this case,
   * your certificate needs to be It is the Base64 encoding of the following JSON Object which is
   * encoded in UTF-8: <br><br> {<br>  "data":"<Base64-encoded-certificate>",<br>
   * "dataType":"pfx",<br>  "password":"<pfx-file-password>"<br>}
  */
  certificateUrl?: string;
  /**
   * For Windows VMs, specifies the certificate store on the Virtual Machine to which the
   * certificate should be added. The specified certificate store is implicitly in the LocalMachine
   * account. <br><br>For Linux VMs, the certificate file is placed under the /var/lib/waagent
   * directory, with the file name &lt;UppercaseThumbprint&gt;.crt for the X509 certificate file
   * and &lt;UppercaseThumbprint&gt;.prv for private key. Both of these files are .pem formatted.
  */
  certificateStore?: string;
}

/**
 * Describes a set of certificates which are all in the same Key Vault.
*/
export interface VaultSecretGroup {
  /**
   * The relative URL of the Key Vault containing all of the certificates in VaultCertificates.
  */
  sourceVault?: SubResource;
  /**
   * The list of key vault references in SourceVault which contain certificates.
  */
  vaultCertificates?: VaultCertificate[];
}

/**
 * Specifies the operating system settings for the virtual machine.
*/
export interface OSProfile {
  /**
   * Specifies the host OS name of the virtual machine. <br><br> This name cannot be updated after
   * the VM is created. <br><br> **Max-length (Windows):** 15 characters <br><br> **Max-length
   * (Linux):** 64 characters. <br><br> For naming conventions and restrictions see [Azure
   * infrastructure services implementation
   * guidelines](https://docs.microsoft.com/azure/virtual-machines/virtual-machines-linux-infrastructure-subscription-accounts-guidelines?toc=%2fazure%2fvirtual-machines%2flinux%2ftoc.json#1-naming-conventions).
  */
  computerName?: string;
  /**
   * Specifies the name of the administrator account. <br><br> **Windows-only restriction:** Cannot
   * end in "." <br><br> **Disallowed values:** "administrator", "admin", "user", "user1", "test",
   * "user2", "test1", "user3", "admin1", "1", "123", "a", "actuser", "adm", "admin2", "aspnet",
   * "backup", "console", "david", "guest", "john", "owner", "root", "server", "sql", "support",
   * "support_388945a0", "sys", "test2", "test3", "user4", "user5". <br><br> **Minimum-length
   * (Linux):** 1  character <br><br> **Max-length (Linux):** 64 characters <br><br> **Max-length
   * (Windows):** 20 characters  <br><br><li> For root access to the Linux VM, see [Using root
   * privileges on Linux virtual machines in
   * Azure](https://docs.microsoft.com/azure/virtual-machines/virtual-machines-linux-use-root-privileges?toc=%2fazure%2fvirtual-machines%2flinux%2ftoc.json)<br><li>
   * For a list of built-in system users on Linux that should not be used in this field, see
   * [Selecting User Names for Linux on
   * Azure](https://docs.microsoft.com/azure/virtual-machines/virtual-machines-linux-usernames?toc=%2fazure%2fvirtual-machines%2flinux%2ftoc.json)
  */
  adminUsername?: string;
  /**
   * Specifies the password of the administrator account. <br><br> **Minimum-length (Windows):** 8
   * characters <br><br> **Minimum-length (Linux):** 6 characters <br><br> **Max-length
   * (Windows):** 123 characters <br><br> **Max-length (Linux):** 72 characters <br><br>
   * **Complexity requirements:** 3 out of 4 conditions below need to be fulfilled <br> Has lower
   * characters <br>Has upper characters <br> Has a digit <br> Has a special character (Regex match
   * [\W_]) <br><br> **Disallowed values:** "abc@123", "P@$$w0rd", "P@ssw0rd", "P@ssword123",
   * "Pa$$word", "pass@word1", "Password!", "Password1", "Password22", "iloveyou!" <br><br> For
   * resetting the password, see [How to reset the Remote Desktop service or its login password in
   * a Windows
   * VM](https://docs.microsoft.com/azure/virtual-machines/virtual-machines-windows-reset-rdp?toc=%2fazure%2fvirtual-machines%2fwindows%2ftoc.json)
   * <br><br> For resetting root password, see [Manage users, SSH, and check or repair disks on
   * Azure Linux VMs using the VMAccess
   * Extension](https://docs.microsoft.com/azure/virtual-machines/virtual-machines-linux-using-vmaccess-extension?toc=%2fazure%2fvirtual-machines%2flinux%2ftoc.json#reset-root-password)
  */
  adminPassword?: string;
  /**
   * Specifies a base-64 encoded string of custom data. The base-64 encoded string is decoded to a
   * binary array that is saved as a file on the Virtual Machine. The maximum length of the binary
   * array is 65535 bytes. <br><br> For using cloud-init for your VM, see [Using cloud-init to
   * customize a Linux VM during
   * creation](https://docs.microsoft.com/azure/virtual-machines/virtual-machines-linux-using-cloud-init?toc=%2fazure%2fvirtual-machines%2flinux%2ftoc.json)
  */
  customData?: string;
  /**
   * Specifies Windows operating system settings on the virtual machine.
  */
  windowsConfiguration?: WindowsConfiguration;
  /**
   * Specifies the Linux operating system settings on the virtual machine. <br><br>For a list of
   * supported Linux distributions, see [Linux on Azure-Endorsed
   * Distributions](https://docs.microsoft.com/azure/virtual-machines/virtual-machines-linux-endorsed-distros?toc=%2fazure%2fvirtual-machines%2flinux%2ftoc.json)
   * <br><br> For running non-endorsed distributions, see [Information for Non-Endorsed
   * Distributions](https://docs.microsoft.com/azure/virtual-machines/virtual-machines-linux-create-upload-generic?toc=%2fazure%2fvirtual-machines%2flinux%2ftoc.json).
  */
  linuxConfiguration?: LinuxConfiguration;
  /**
   * Specifies set of certificates that should be installed onto the virtual machine.
  */
  secrets?: VaultSecretGroup[];
  /**
   * Specifies whether extension operations should be allowed on the virtual machine. <br><br>This
   * may only be set to False when no extensions are present on the virtual machine.
  */
  allowExtensionOperations?: boolean;
}

/**
 * Describes a network interface reference.
*/
export interface NetworkInterfaceReference extends SubResource {
  /**
   * Specifies the primary network interface in case the virtual machine has more than 1 network
   * interface.
  */
  primary?: boolean;
}

/**
 * Specifies the network interfaces of the virtual machine.
*/
export interface NetworkProfile {
  /**
   * Specifies the list of resource Ids for the network interfaces associated with the virtual
   * machine.
  */
  networkInterfaces?: NetworkInterfaceReference[];
}

/**
 * Boot Diagnostics is a debugging feature which allows you to view Console Output and Screenshot
 * to diagnose VM status. <br><br> You can easily view the output of your console log. <br><br>
 * Azure also enables you to see a screenshot of the VM from the hypervisor.
*/
export interface BootDiagnostics {
  /**
   * Whether boot diagnostics should be enabled on the Virtual Machine.
  */
  enabled?: boolean;
  /**
   * Uri of the storage account to use for placing the console output and screenshot.
  */
  storageUri?: string;
}

/**
 * Specifies the boot diagnostic settings state. <br><br>Minimum api-version: 2015-06-15.
*/
export interface DiagnosticsProfile {
  /**
   * Boot Diagnostics is a debugging feature which allows you to view Console Output and Screenshot
   * to diagnose VM status. <br><br> You can easily view the output of your console log. <br><br>
   * Azure also enables you to see a screenshot of the VM from the hypervisor.
  */
  bootDiagnostics?: BootDiagnostics;
}

/**
 * The instance view of a virtual machine extension handler.
*/
export interface VirtualMachineExtensionHandlerInstanceView {
  /**
   * Specifies the type of the extension; an example is "CustomScriptExtension".
  */
  type?: string;
  /**
   * Specifies the version of the script handler.
  */
  typeHandlerVersion?: string;
  /**
   * The extension handler status.
  */
  status?: InstanceViewStatus;
}

/**
 * The instance view of the VM Agent running on the virtual machine.
*/
export interface VirtualMachineAgentInstanceView {
  /**
   * The VM Agent full version.
  */
  vmAgentVersion?: string;
  /**
   * The virtual machine extension handler instance view.
  */
  extensionHandlers?: VirtualMachineExtensionHandlerInstanceView[];
  /**
   * The resource status information.
  */
  statuses?: InstanceViewStatus[];
}

/**
 * The instance view of the disk.
*/
export interface DiskInstanceView {
  /**
   * The disk name.
  */
  name?: string;
  /**
   * Specifies the encryption settings for the OS Disk. <br><br> Minimum api-version: 2015-06-15
  */
  encryptionSettings?: DiskEncryptionSettings[];
  /**
   * The resource status information.
  */
  statuses?: InstanceViewStatus[];
}

/**
 * The instance view of a virtual machine boot diagnostics.
*/
export interface BootDiagnosticsInstanceView {
  /**
   * The console screenshot blob URI.
  */
  readonly consoleScreenshotBlobUri?: string;
  /**
   * The Linux serial console log blob Uri.
  */
  readonly serialConsoleLogBlobUri?: string;
  /**
   * The boot diagnostics status information for the VM. <br><br> NOTE: It will be set only if
   * there are errors encountered in enabling boot diagnostics.
  */
  readonly status?: InstanceViewStatus;
}

export interface VirtualMachineIdentityUserAssignedIdentitiesValue {
  /**
   * The principal id of user assigned identity.
  */
  readonly principalId?: string;
  /**
   * The client id of user assigned identity.
  */
  readonly clientId?: string;
}

/**
 * Identity for the virtual machine.
*/
export interface VirtualMachineIdentity {
  /**
   * The principal id of virtual machine identity. This property will only be provided for a system
   * assigned identity.
  */
  readonly principalId?: string;
  /**
   * The tenant id associated with the virtual machine. This property will only be provided for a
   * system assigned identity.
  */
  readonly tenantId?: string;
  /**
   * The type of identity used for the virtual machine. The type 'SystemAssigned, UserAssigned'
   * includes both an implicitly created identity and a set of user assigned identities. The type
   * 'None' will remove any identities from the virtual machine. Possible values include:
   * 'SystemAssigned', 'UserAssigned', 'SystemAssigned, UserAssigned', 'None'
  */
  type?: string;
  /**
   * The list of user identities associated with the Virtual Machine. The user identity dictionary
   * key references will be ARM resource ids in the form:
   * '/subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/Microsoft.ManagedIdentity/userAssignedIdentities/{identityName}'.
  */
  userAssignedIdentities?: { [propertyName: string]:
  VirtualMachineIdentityUserAssignedIdentitiesValue };
}

/**
 * Maintenance Operation Status.
*/
export interface MaintenanceRedeployStatus {
  /**
   * True, if customer is allowed to perform Maintenance.
  */
  isCustomerInitiatedMaintenanceAllowed?: boolean;
  /**
   * Start Time for the Pre Maintenance Window.
  */
  preMaintenanceWindowStartTime?: Date;
  /**
   * End Time for the Pre Maintenance Window.
  */
  preMaintenanceWindowEndTime?: Date;
  /**
   * Start Time for the Maintenance Window.
  */
  maintenanceWindowStartTime?: Date;
  /**
   * End Time for the Maintenance Window.
  */
  maintenanceWindowEndTime?: Date;
  /**
   * The Last Maintenance Operation Result Code. Possible values include: 'None', 'RetryLater',
   * 'MaintenanceAborted', 'MaintenanceCompleted'
  */
  lastOperationResultCode?: string;
  /**
   * Message returned for the last Maintenance Operation.
  */
  lastOperationMessage?: string;
}

/**
 * The instance view of a virtual machine.
*/
export interface VirtualMachineInstanceView {
  /**
   * Specifies the update domain of the virtual machine.
  */
  platformUpdateDomain?: number;
  /**
   * Specifies the fault domain of the virtual machine.
  */
  platformFaultDomain?: number;
  /**
   * The computer name assigned to the virtual machine.
  */
  computerName?: string;
  /**
   * The Operating System running on the virtual machine.
  */
  osName?: string;
  /**
   * The version of Operating System running on the virtual machine.
  */
  osVersion?: string;
  /**
   * The Remote desktop certificate thumbprint.
  */
  rdpThumbPrint?: string;
  /**
   * The VM Agent running on the virtual machine.
  */
  vmAgent?: VirtualMachineAgentInstanceView;
  /**
   * The Maintenance Operation status on the virtual machine.
  */
  maintenanceRedeployStatus?: MaintenanceRedeployStatus;
  /**
   * The virtual machine disk information.
  */
  disks?: DiskInstanceView[];
  /**
   * The extensions information.
  */
  extensions?: VirtualMachineExtensionInstanceView[];
  /**
   * Boot Diagnostics is a debugging feature which allows you to view Console Output and Screenshot
   * to diagnose VM status. <br><br> You can easily view the output of your console log. <br><br>
   * Azure also enables you to see a screenshot of the VM from the hypervisor.
  */
  bootDiagnostics?: BootDiagnosticsInstanceView;
  /**
   * The resource status information.
  */
  statuses?: InstanceViewStatus[];
}

/**
 * Describes a Virtual Machine.
*/
export interface VirtualMachine extends Resource {
  /**
   * Specifies information about the marketplace image used to create the virtual machine. This
   * element is only used for marketplace images. Before you can use a marketplace image from an
   * API, you must enable the image for programmatic use.  In the Azure portal, find the
   * marketplace image that you want to use and then click **Want to deploy programmatically, Get
   * Started ->**. Enter any required information and then click **Save**.
  */
  plan?: Plan;
  /**
   * Specifies the hardware settings for the virtual machine.
  */
  hardwareProfile?: HardwareProfile;
  /**
   * Specifies the storage settings for the virtual machine disks.
  */
  storageProfile?: StorageProfile;
  /**
   * Specifies additional capabilities enabled or disabled on the virtual machine.
  */
  additionalCapabilities?: AdditionalCapabilities;
  /**
   * Specifies the operating system settings for the virtual machine.
  */
  osProfile?: OSProfile;
  /**
   * Specifies the network interfaces of the virtual machine.
  */
  networkProfile?: NetworkProfile;
  /**
   * Specifies the boot diagnostic settings state. <br><br>Minimum api-version: 2015-06-15.
  */
  diagnosticsProfile?: DiagnosticsProfile;
  /**
   * Specifies information about the availability set that the virtual machine should be assigned
   * to. Virtual machines specified in the same availability set are allocated to different nodes
   * to maximize availability. For more information about availability sets, see [Manage the
   * availability of virtual
   * machines](https://docs.microsoft.com/azure/virtual-machines/virtual-machines-windows-manage-availability?toc=%2fazure%2fvirtual-machines%2fwindows%2ftoc.json).
   * <br><br> For more information on Azure planned maintenance, see [Planned maintenance for
   * virtual machines in
   * Azure](https://docs.microsoft.com/azure/virtual-machines/virtual-machines-windows-planned-maintenance?toc=%2fazure%2fvirtual-machines%2fwindows%2ftoc.json)
   * <br><br> Currently, a VM can only be added to availability set at creation time. An existing
   * VM cannot be added to an availability set.
  */
  availabilitySet?: SubResource;
  /**
   * The provisioning state, which only appears in the response.
  */
  readonly provisioningState?: string;
  /**
   * The virtual machine instance view.
  */
  readonly instanceView?: VirtualMachineInstanceView;
  /**
   * Specifies that the image or disk that is being used was licensed on-premises. This element is
   * only used for images that contain the Windows Server operating system. <br><br> Possible
   * values are: <br><br> Windows_Client <br><br> Windows_Server <br><br> If this element is
   * included in a request for an update, the value must match the initial value. This value cannot
   * be updated. <br><br> For more information, see [Azure Hybrid Use Benefit for Windows
   * Server](https://docs.microsoft.com/azure/virtual-machines/virtual-machines-windows-hybrid-use-benefit-licensing?toc=%2fazure%2fvirtual-machines%2fwindows%2ftoc.json)
   * <br><br> Minimum api-version: 2015-06-15
  */
  licenseType?: string;
  /**
   * Specifies the VM unique ID which is a 128-bits identifier that is encoded and stored in all
   * Azure IaaS VMs SMBIOS and can be read using platform BIOS commands.
  */
  readonly vmId?: string;
  /**
   * The virtual machine child extension resources.
  */
  readonly resources?: VirtualMachineExtension[];
  /**
   * The identity of the virtual machine, if configured.
  */
  identity?: VirtualMachineIdentity;
  /**
   * The virtual machine zones.
  */
  zones?: string[];
}

/**
 * Describes a Virtual Machine Update.
*/
export interface VirtualMachineUpdate extends UpdateResource {
  /**
   * Specifies information about the marketplace image used to create the virtual machine. This
   * element is only used for marketplace images. Before you can use a marketplace image from an
   * API, you must enable the image for programmatic use.  In the Azure portal, find the
   * marketplace image that you want to use and then click **Want to deploy programmatically, Get
   * Started ->**. Enter any required information and then click **Save**.
  */
  plan?: Plan;
  /**
   * Specifies the hardware settings for the virtual machine.
  */
  hardwareProfile?: HardwareProfile;
  /**
   * Specifies the storage settings for the virtual machine disks.
  */
  storageProfile?: StorageProfile;
  /**
   * Specifies additional capabilities enabled or disabled on the virtual machine.
  */
  additionalCapabilities?: AdditionalCapabilities;
  /**
   * Specifies the operating system settings for the virtual machine.
  */
  osProfile?: OSProfile;
  /**
   * Specifies the network interfaces of the virtual machine.
  */
  networkProfile?: NetworkProfile;
  /**
   * Specifies the boot diagnostic settings state. <br><br>Minimum api-version: 2015-06-15.
  */
  diagnosticsProfile?: DiagnosticsProfile;
  /**
   * Specifies information about the availability set that the virtual machine should be assigned
   * to. Virtual machines specified in the same availability set are allocated to different nodes
   * to maximize availability. For more information about availability sets, see [Manage the
   * availability of virtual
   * machines](https://docs.microsoft.com/azure/virtual-machines/virtual-machines-windows-manage-availability?toc=%2fazure%2fvirtual-machines%2fwindows%2ftoc.json).
   * <br><br> For more information on Azure planned maintenance, see [Planned maintenance for
   * virtual machines in
   * Azure](https://docs.microsoft.com/azure/virtual-machines/virtual-machines-windows-planned-maintenance?toc=%2fazure%2fvirtual-machines%2fwindows%2ftoc.json)
   * <br><br> Currently, a VM can only be added to availability set at creation time. An existing
   * VM cannot be added to an availability set.
  */
  availabilitySet?: SubResource;
  /**
   * The provisioning state, which only appears in the response.
  */
  readonly provisioningState?: string;
  /**
   * The virtual machine instance view.
  */
  readonly instanceView?: VirtualMachineInstanceView;
  /**
   * Specifies that the image or disk that is being used was licensed on-premises. This element is
   * only used for images that contain the Windows Server operating system. <br><br> Possible
   * values are: <br><br> Windows_Client <br><br> Windows_Server <br><br> If this element is
   * included in a request for an update, the value must match the initial value. This value cannot
   * be updated. <br><br> For more information, see [Azure Hybrid Use Benefit for Windows
   * Server](https://docs.microsoft.com/azure/virtual-machines/virtual-machines-windows-hybrid-use-benefit-licensing?toc=%2fazure%2fvirtual-machines%2fwindows%2ftoc.json)
   * <br><br> Minimum api-version: 2015-06-15
  */
  licenseType?: string;
  /**
   * Specifies the VM unique ID which is a 128-bits identifier that is encoded and stored in all
   * Azure IaaS VMs SMBIOS and can be read using platform BIOS commands.
  */
  readonly vmId?: string;
  /**
   * The identity of the virtual machine, if configured.
  */
  identity?: VirtualMachineIdentity;
  /**
   * The virtual machine zones.
  */
  zones?: string[];
}

/**
 * The configuration parameters used for performing automatic OS upgrade.
*/
export interface AutomaticOSUpgradePolicy {
  /**
   * Whether OS upgrades should automatically be applied to scale set instances in a rolling
   * fashion when a newer version of the image becomes available. Default value is false.
  */
  enableAutomaticOSUpgrade?: boolean;
  /**
   * Whether OS image rollback feature should be disabled. Default value is false.
  */
  disableAutomaticRollback?: boolean;
}

/**
 * The configuration parameters used while performing a rolling upgrade.
*/
export interface RollingUpgradePolicy {
  /**
   * The maximum percent of total virtual machine instances that will be upgraded simultaneously by
   * the rolling upgrade in one batch. As this is a maximum, unhealthy instances in previous or
   * future batches can cause the percentage of instances in a batch to decrease to ensure higher
   * reliability. The default value for this parameter is 20%.
  */
  maxBatchInstancePercent?: number;
  /**
   * The maximum percentage of the total virtual machine instances in the scale set that can be
   * simultaneously unhealthy, either as a result of being upgraded, or by being found in an
   * unhealthy state by the virtual machine health checks before the rolling upgrade aborts. This
   * constraint will be checked prior to starting any batch. The default value for this parameter
   * is 20%.
  */
  maxUnhealthyInstancePercent?: number;
  /**
   * The maximum percentage of upgraded virtual machine instances that can be found to be in an
   * unhealthy state. This check will happen after each batch is upgraded. If this percentage is
   * ever exceeded, the rolling update aborts. The default value for this parameter is 20%.
  */
  maxUnhealthyUpgradedInstancePercent?: number;
  /**
   * The wait time between completing the update for all virtual machines in one batch and starting
   * the next batch. The time duration should be specified in ISO 8601 format. The default value is
   * 0 seconds (PT0S).
  */
  pauseTimeBetweenBatches?: string;
}

/**
 * Describes an upgrade policy - automatic, manual, or rolling.
*/
export interface UpgradePolicy {
  /**
   * Specifies the mode of an upgrade to virtual machines in the scale set.<br /><br /> Possible
   * values are:<br /><br /> **Manual** - You  control the application of updates to virtual
   * machines in the scale set. You do this by using the manualUpgrade action.<br /><br />
   * **Automatic** - All virtual machines in the scale set are  automatically updated at the same
   * time. Possible values include: 'Automatic', 'Manual', 'Rolling'
  */
  mode?: string;
  /**
   * The configuration parameters used while performing a rolling upgrade.
  */
  rollingUpgradePolicy?: RollingUpgradePolicy;
  /**
   * Configuration parameters used for performing automatic OS Upgrade.
  */
  automaticOSUpgradePolicy?: AutomaticOSUpgradePolicy;
}

/**
 * Describes an Operating System disk.
*/
export interface ImageOSDisk {
  /**
   * This property allows you to specify the type of the OS that is included in the disk if
   * creating a VM from a custom image. <br><br> Possible values are: <br><br> **Windows** <br><br>
   * **Linux**. Possible values include: 'Windows', 'Linux'
  */
  osType: string;
  /**
   * The OS State. Possible values include: 'Generalized', 'Specialized'
  */
  osState: string;
  /**
   * The snapshot.
  */
  snapshot?: SubResource;
  /**
   * The managedDisk.
  */
  managedDisk?: SubResource;
  /**
   * The Virtual Hard Disk.
  */
  blobUri?: string;
  /**
   * Specifies the caching requirements. <br><br> Possible values are: <br><br> **None** <br><br>
   * **ReadOnly** <br><br> **ReadWrite** <br><br> Default: **None for Standard storage. ReadOnly
   * for Premium storage**. Possible values include: 'None', 'ReadOnly', 'ReadWrite'
  */
  caching?: string;
  /**
   * Specifies the size of empty data disks in gigabytes. This element can be used to overwrite the
   * name of the disk in a virtual machine image. <br><br> This value cannot be larger than 1023 GB
  */
  diskSizeGB?: number;
  /**
   * Specifies the storage account type for the managed disk. UltraSSD_LRS cannot be used with OS
   * Disk. Possible values include: 'Standard_LRS', 'Premium_LRS', 'StandardSSD_LRS',
   * 'UltraSSD_LRS'
  */
  storageAccountType?: string;
}

/**
 * Describes a data disk.
*/
export interface ImageDataDisk {
  /**
   * Specifies the logical unit number of the data disk. This value is used to identify data disks
   * within the VM and therefore must be unique for each data disk attached to a VM.
  */
  lun: number;
  /**
   * The snapshot.
  */
  snapshot?: SubResource;
  /**
   * The managedDisk.
  */
  managedDisk?: SubResource;
  /**
   * The Virtual Hard Disk.
  */
  blobUri?: string;
  /**
   * Specifies the caching requirements. <br><br> Possible values are: <br><br> **None** <br><br>
   * **ReadOnly** <br><br> **ReadWrite** <br><br> Default: **None for Standard storage. ReadOnly
   * for Premium storage**. Possible values include: 'None', 'ReadOnly', 'ReadWrite'
  */
  caching?: string;
  /**
   * Specifies the size of empty data disks in gigabytes. This element can be used to overwrite the
   * name of the disk in a virtual machine image. <br><br> This value cannot be larger than 1023 GB
  */
  diskSizeGB?: number;
  /**
   * Specifies the storage account type for the managed disk. NOTE: UltraSSD_LRS can only be used
   * with data disks, it cannot be used with OS Disk. Possible values include: 'Standard_LRS',
   * 'Premium_LRS', 'StandardSSD_LRS', 'UltraSSD_LRS'
  */
  storageAccountType?: string;
}

/**
 * Describes a storage profile.
*/
export interface ImageStorageProfile {
  /**
   * Specifies information about the operating system disk used by the virtual machine. <br><br>
   * For more information about disks, see [About disks and VHDs for Azure virtual
   * machines](https://docs.microsoft.com/azure/virtual-machines/virtual-machines-windows-about-disks-vhds?toc=%2fazure%2fvirtual-machines%2fwindows%2ftoc.json).
  */
  osDisk?: ImageOSDisk;
  /**
   * Specifies the parameters that are used to add a data disk to a virtual machine. <br><br> For
   * more information about disks, see [About disks and VHDs for Azure virtual
   * machines](https://docs.microsoft.com/azure/virtual-machines/virtual-machines-windows-about-disks-vhds?toc=%2fazure%2fvirtual-machines%2fwindows%2ftoc.json).
  */
  dataDisks?: ImageDataDisk[];
  /**
   * Specifies whether an image is zone resilient or not. Default is false. Zone resilient images
   * can be created only in regions that provide Zone Redundant Storage (ZRS).
  */
  zoneResilient?: boolean;
}

/**
 * The source user image virtual hard disk. The virtual hard disk will be copied before being
 * attached to the virtual machine. If SourceImage is provided, the destination virtual hard drive
 * must not exist.
*/
export interface Image extends Resource {
  /**
   * The source virtual machine from which Image is created.
  */
  sourceVirtualMachine?: SubResource;
  /**
   * Specifies the storage settings for the virtual machine disks.
  */
  storageProfile?: ImageStorageProfile;
  /**
   * The provisioning state.
  */
  readonly provisioningState?: string;
}

/**
 * The source user image virtual hard disk. Only tags may be updated.
*/
export interface ImageUpdate extends UpdateResource {
  /**
   * The source virtual machine from which Image is created.
  */
  sourceVirtualMachine?: SubResource;
  /**
   * Specifies the storage settings for the virtual machine disks.
  */
  storageProfile?: ImageStorageProfile;
  /**
   * The provisioning state.
  */
  readonly provisioningState?: string;
}

export interface VirtualMachineScaleSetIdentityUserAssignedIdentitiesValue {
  /**
   * The principal id of user assigned identity.
  */
  readonly principalId?: string;
  /**
   * The client id of user assigned identity.
  */
  readonly clientId?: string;
}

/**
 * Identity for the virtual machine scale set.
*/
export interface VirtualMachineScaleSetIdentity {
  /**
   * The principal id of virtual machine scale set identity. This property will only be provided
   * for a system assigned identity.
  */
  readonly principalId?: string;
  /**
   * The tenant id associated with the virtual machine scale set. This property will only be
   * provided for a system assigned identity.
  */
  readonly tenantId?: string;
  /**
   * The type of identity used for the virtual machine scale set. The type 'SystemAssigned,
   * UserAssigned' includes both an implicitly created identity and a set of user assigned
   * identities. The type 'None' will remove any identities from the virtual machine scale set.
   * Possible values include: 'SystemAssigned', 'UserAssigned', 'SystemAssigned, UserAssigned',
   * 'None'
  */
  type?: string;
  /**
   * The list of user identities associated with the virtual machine scale set. The user identity
   * dictionary key references will be ARM resource ids in the form:
   * '/subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/Microsoft.ManagedIdentity/userAssignedIdentities/{identityName}'.
  */
  userAssignedIdentities?: { [propertyName: string]:
  VirtualMachineScaleSetIdentityUserAssignedIdentitiesValue };
}

/**
 * Describes a virtual machine scale set OS profile.
*/
export interface VirtualMachineScaleSetOSProfile {
  /**
   * Specifies the computer name prefix for all of the virtual machines in the scale set. Computer
   * name prefixes must be 1 to 15 characters long.
  */
  computerNamePrefix?: string;
  /**
   * Specifies the name of the administrator account. <br><br> **Windows-only restriction:** Cannot
   * end in "." <br><br> **Disallowed values:** "administrator", "admin", "user", "user1", "test",
   * "user2", "test1", "user3", "admin1", "1", "123", "a", "actuser", "adm", "admin2", "aspnet",
   * "backup", "console", "david", "guest", "john", "owner", "root", "server", "sql", "support",
   * "support_388945a0", "sys", "test2", "test3", "user4", "user5". <br><br> **Minimum-length
   * (Linux):** 1  character <br><br> **Max-length (Linux):** 64 characters <br><br> **Max-length
   * (Windows):** 20 characters  <br><br><li> For root access to the Linux VM, see [Using root
   * privileges on Linux virtual machines in
   * Azure](https://docs.microsoft.com/azure/virtual-machines/virtual-machines-linux-use-root-privileges?toc=%2fazure%2fvirtual-machines%2flinux%2ftoc.json)<br><li>
   * For a list of built-in system users on Linux that should not be used in this field, see
   * [Selecting User Names for Linux on
   * Azure](https://docs.microsoft.com/azure/virtual-machines/virtual-machines-linux-usernames?toc=%2fazure%2fvirtual-machines%2flinux%2ftoc.json)
  */
  adminUsername?: string;
  /**
   * Specifies the password of the administrator account. <br><br> **Minimum-length (Windows):** 8
   * characters <br><br> **Minimum-length (Linux):** 6 characters <br><br> **Max-length
   * (Windows):** 123 characters <br><br> **Max-length (Linux):** 72 characters <br><br>
   * **Complexity requirements:** 3 out of 4 conditions below need to be fulfilled <br> Has lower
   * characters <br>Has upper characters <br> Has a digit <br> Has a special character (Regex match
   * [\W_]) <br><br> **Disallowed values:** "abc@123", "P@$$w0rd", "P@ssw0rd", "P@ssword123",
   * "Pa$$word", "pass@word1", "Password!", "Password1", "Password22", "iloveyou!" <br><br> For
   * resetting the password, see [How to reset the Remote Desktop service or its login password in
   * a Windows
   * VM](https://docs.microsoft.com/azure/virtual-machines/virtual-machines-windows-reset-rdp?toc=%2fazure%2fvirtual-machines%2fwindows%2ftoc.json)
   * <br><br> For resetting root password, see [Manage users, SSH, and check or repair disks on
   * Azure Linux VMs using the VMAccess
   * Extension](https://docs.microsoft.com/azure/virtual-machines/virtual-machines-linux-using-vmaccess-extension?toc=%2fazure%2fvirtual-machines%2flinux%2ftoc.json#reset-root-password)
  */
  adminPassword?: string;
  /**
   * Specifies a base-64 encoded string of custom data. The base-64 encoded string is decoded to a
   * binary array that is saved as a file on the Virtual Machine. The maximum length of the binary
   * array is 65535 bytes. <br><br> For using cloud-init for your VM, see [Using cloud-init to
   * customize a Linux VM during
   * creation](https://docs.microsoft.com/azure/virtual-machines/virtual-machines-linux-using-cloud-init?toc=%2fazure%2fvirtual-machines%2flinux%2ftoc.json)
  */
  customData?: string;
  /**
   * Specifies Windows operating system settings on the virtual machine.
  */
  windowsConfiguration?: WindowsConfiguration;
  /**
   * Specifies the Linux operating system settings on the virtual machine. <br><br>For a list of
   * supported Linux distributions, see [Linux on Azure-Endorsed
   * Distributions](https://docs.microsoft.com/azure/virtual-machines/virtual-machines-linux-endorsed-distros?toc=%2fazure%2fvirtual-machines%2flinux%2ftoc.json)
   * <br><br> For running non-endorsed distributions, see [Information for Non-Endorsed
   * Distributions](https://docs.microsoft.com/azure/virtual-machines/virtual-machines-linux-create-upload-generic?toc=%2fazure%2fvirtual-machines%2flinux%2ftoc.json).
  */
  linuxConfiguration?: LinuxConfiguration;
  /**
   * Specifies set of certificates that should be installed onto the virtual machines in the scale
   * set.
  */
  secrets?: VaultSecretGroup[];
}

/**
 * Describes a virtual machine scale set OS profile.
*/
export interface VirtualMachineScaleSetUpdateOSProfile {
  /**
   * A base-64 encoded string of custom data.
  */
  customData?: string;
  /**
   * The Windows Configuration of the OS profile.
  */
  windowsConfiguration?: WindowsConfiguration;
  /**
   * The Linux Configuration of the OS profile.
  */
  linuxConfiguration?: LinuxConfiguration;
  /**
   * The List of certificates for addition to the VM.
  */
  secrets?: VaultSecretGroup[];
}

/**
 * Describes the parameters of a ScaleSet managed disk.
*/
export interface VirtualMachineScaleSetManagedDiskParameters {
  /**
   * Specifies the storage account type for the managed disk. NOTE: UltraSSD_LRS can only be used
   * with data disks, it cannot be used with OS Disk. Possible values include: 'Standard_LRS',
   * 'Premium_LRS', 'StandardSSD_LRS', 'UltraSSD_LRS'
  */
  storageAccountType?: string;
}

/**
 * Describes a virtual machine scale set operating system disk.
*/
export interface VirtualMachineScaleSetOSDisk {
  /**
   * The disk name.
  */
  name?: string;
  /**
   * Specifies the caching requirements. <br><br> Possible values are: <br><br> **None** <br><br>
   * **ReadOnly** <br><br> **ReadWrite** <br><br> Default: **None for Standard storage. ReadOnly
   * for Premium storage**. Possible values include: 'None', 'ReadOnly', 'ReadWrite'
  */
  caching?: string;
  /**
   * Specifies whether writeAccelerator should be enabled or disabled on the disk.
  */
  writeAcceleratorEnabled?: boolean;
  /**
   * Specifies how the virtual machines in the scale set should be created.<br><br> The only
   * allowed value is: **FromImage** \u2013 This value is used when you are using an image to
   * create the virtual machine. If you are using a platform image, you also use the imageReference
   * element described above. If you are using a marketplace image, you  also use the plan element
   * previously described. Possible values include: 'FromImage', 'Empty', 'Attach'
  */
  createOption: string;
  /**
   * Specifies the ephemeral disk Settings for the operating system disk used by the virtual
   * machine scale set.
  */
  diffDiskSettings?: DiffDiskSettings;
  /**
   * Specifies the size of the operating system disk in gigabytes. This element can be used to
   * overwrite the size of the disk in a virtual machine image. <br><br> This value cannot be
   * larger than 1023 GB
  */
  diskSizeGB?: number;
  /**
   * This property allows you to specify the type of the OS that is included in the disk if
   * creating a VM from user-image or a specialized VHD. <br><br> Possible values are: <br><br>
   * **Windows** <br><br> **Linux**. Possible values include: 'Windows', 'Linux'
  */
  osType?: string;
  /**
   * Specifies information about the unmanaged user image to base the scale set on.
  */
  image?: VirtualHardDisk;
  /**
   * Specifies the container urls that are used to store operating system disks for the scale set.
  */
  vhdContainers?: string[];
  /**
   * The managed disk parameters.
  */
  managedDisk?: VirtualMachineScaleSetManagedDiskParameters;
}

/**
 * Describes virtual machine scale set operating system disk Update Object. This should be used for
 * Updating VMSS OS Disk.
*/
export interface VirtualMachineScaleSetUpdateOSDisk {
  /**
   * The caching type. Possible values include: 'None', 'ReadOnly', 'ReadWrite'
  */
  caching?: string;
  /**
   * Specifies whether writeAccelerator should be enabled or disabled on the disk.
  */
  writeAcceleratorEnabled?: boolean;
  /**
   * Specifies the size of the operating system disk in gigabytes. This element can be used to
   * overwrite the size of the disk in a virtual machine image. <br><br> This value cannot be
   * larger than 1023 GB
  */
  diskSizeGB?: number;
  /**
   * The Source User Image VirtualHardDisk. This VirtualHardDisk will be copied before using it to
   * attach to the Virtual Machine. If SourceImage is provided, the destination VirtualHardDisk
   * should not exist.
  */
  image?: VirtualHardDisk;
  /**
   * The list of virtual hard disk container uris.
  */
  vhdContainers?: string[];
  /**
   * The managed disk parameters.
  */
  managedDisk?: VirtualMachineScaleSetManagedDiskParameters;
}

/**
 * Describes a virtual machine scale set data disk.
*/
export interface VirtualMachineScaleSetDataDisk {
  /**
   * The disk name.
  */
  name?: string;
  /**
   * Specifies the logical unit number of the data disk. This value is used to identify data disks
   * within the VM and therefore must be unique for each data disk attached to a VM.
  */
  lun: number;
  /**
   * Specifies the caching requirements. <br><br> Possible values are: <br><br> **None** <br><br>
   * **ReadOnly** <br><br> **ReadWrite** <br><br> Default: **None for Standard storage. ReadOnly
   * for Premium storage**. Possible values include: 'None', 'ReadOnly', 'ReadWrite'
  */
  caching?: string;
  /**
   * Specifies whether writeAccelerator should be enabled or disabled on the disk.
  */
  writeAcceleratorEnabled?: boolean;
  /**
   * The create option. Possible values include: 'FromImage', 'Empty', 'Attach'
  */
  createOption: string;
  /**
   * Specifies the size of an empty data disk in gigabytes. This element can be used to overwrite
   * the size of the disk in a virtual machine image. <br><br> This value cannot be larger than
   * 1023 GB
  */
  diskSizeGB?: number;
  /**
   * The managed disk parameters.
  */
  managedDisk?: VirtualMachineScaleSetManagedDiskParameters;
}

/**
 * Describes a virtual machine scale set storage profile.
*/
export interface VirtualMachineScaleSetStorageProfile {
  /**
   * Specifies information about the image to use. You can specify information about platform
   * images, marketplace images, or virtual machine images. This element is required when you want
   * to use a platform image, marketplace image, or virtual machine image, but is not used in other
   * creation operations.
  */
  imageReference?: ImageReference;
  /**
   * Specifies information about the operating system disk used by the virtual machines in the
   * scale set. <br><br> For more information about disks, see [About disks and VHDs for Azure
   * virtual
   * machines](https://docs.microsoft.com/azure/virtual-machines/virtual-machines-windows-about-disks-vhds?toc=%2fazure%2fvirtual-machines%2fwindows%2ftoc.json).
  */
  osDisk?: VirtualMachineScaleSetOSDisk;
  /**
   * Specifies the parameters that are used to add data disks to the virtual machines in the scale
   * set. <br><br> For more information about disks, see [About disks and VHDs for Azure virtual
   * machines](https://docs.microsoft.com/azure/virtual-machines/virtual-machines-windows-about-disks-vhds?toc=%2fazure%2fvirtual-machines%2fwindows%2ftoc.json).
  */
  dataDisks?: VirtualMachineScaleSetDataDisk[];
}

/**
 * Describes a virtual machine scale set storage profile.
*/
export interface VirtualMachineScaleSetUpdateStorageProfile {
  /**
   * The image reference.
  */
  imageReference?: ImageReference;
  /**
   * The OS disk.
  */
  osDisk?: VirtualMachineScaleSetUpdateOSDisk;
  /**
   * The data disks.
  */
  dataDisks?: VirtualMachineScaleSetDataDisk[];
}

/**
 * The API entity reference.
*/
export interface ApiEntityReference {
  /**
   * The ARM resource id in the form of
   * /subscriptions/{SubscriptionId}/resourceGroups/{ResourceGroupName}/...
  */
  id?: string;
}

/**
 * Describes a virtual machines scale sets network configuration's DNS settings.
*/
export interface VirtualMachineScaleSetPublicIPAddressConfigurationDnsSettings {
  /**
   * The Domain name label.The concatenation of the domain name label and vm index will be the
   * domain name labels of the PublicIPAddress resources that will be created
  */
  domainNameLabel: string;
}

/**
 * Contains the IP tag associated with the public IP address.
*/
export interface VirtualMachineScaleSetIpTag {
  /**
   * IP tag type. Example: FirstPartyUsage.
  */
  ipTagType?: string;
  /**
   * IP tag associated with the public IP. Example: SQL, Storage etc.
  */
  tag?: string;
}

/**
 * Describes a virtual machines scale set IP Configuration's PublicIPAddress configuration
*/
export interface VirtualMachineScaleSetPublicIPAddressConfiguration {
  /**
   * The publicIP address configuration name.
  */
  name: string;
  /**
   * The idle timeout of the public IP address.
  */
  idleTimeoutInMinutes?: number;
  /**
   * The dns settings to be applied on the publicIP addresses .
  */
  dnsSettings?: VirtualMachineScaleSetPublicIPAddressConfigurationDnsSettings;
  /**
   * The list of IP tags associated with the public IP address.
  */
  ipTags?: VirtualMachineScaleSetIpTag[];
  /**
   * The PublicIPPrefix from which to allocate publicIP addresses.
  */
  publicIPPrefix?: SubResource;
}

/**
 * Describes a virtual machines scale set IP Configuration's PublicIPAddress configuration
*/
export interface VirtualMachineScaleSetUpdatePublicIPAddressConfiguration {
  /**
   * The publicIP address configuration name.
  */
  name?: string;
  /**
   * The idle timeout of the public IP address.
  */
  idleTimeoutInMinutes?: number;
  /**
   * The dns settings to be applied on the publicIP addresses .
  */
  dnsSettings?: VirtualMachineScaleSetPublicIPAddressConfigurationDnsSettings;
}

/**
 * Describes a virtual machine scale set network profile's IP configuration.
*/
export interface VirtualMachineScaleSetIPConfiguration extends SubResource {
  /**
   * The IP configuration name.
  */
  name: string;
  /**
   * Specifies the identifier of the subnet.
  */
  subnet?: ApiEntityReference;
  /**
   * Specifies the primary network interface in case the virtual machine has more than 1 network
   * interface.
  */
  primary?: boolean;
  /**
   * The publicIPAddressConfiguration.
  */
  publicIPAddressConfiguration?: VirtualMachineScaleSetPublicIPAddressConfiguration;
  /**
   * Available from Api-Version 2017-03-30 onwards, it represents whether the specific
   * ipconfiguration is IPv4 or IPv6. Default is taken as IPv4.  Possible values are: 'IPv4' and
   * 'IPv6'. Possible values include: 'IPv4', 'IPv6'
  */
  privateIPAddressVersion?: string;
  /**
   * Specifies an array of references to backend address pools of application gateways. A scale set
   * can reference backend address pools of multiple application gateways. Multiple scale sets
   * cannot use the same application gateway.
  */
  applicationGatewayBackendAddressPools?: SubResource[];
  /**
   * Specifies an array of references to application security group.
  */
  applicationSecurityGroups?: SubResource[];
  /**
   * Specifies an array of references to backend address pools of load balancers. A scale set can
   * reference backend address pools of one public and one internal load balancer. Multiple scale
   * sets cannot use the same load balancer.
  */
  loadBalancerBackendAddressPools?: SubResource[];
  /**
   * Specifies an array of references to inbound Nat pools of the load balancers. A scale set can
   * reference inbound nat pools of one public and one internal load balancer. Multiple scale sets
   * cannot use the same load balancer
  */
  loadBalancerInboundNatPools?: SubResource[];
}

/**
 * Describes a virtual machine scale set network profile's IP configuration.
*/
export interface VirtualMachineScaleSetUpdateIPConfiguration extends SubResource {
  /**
   * The IP configuration name.
  */
  name?: string;
  /**
   * The subnet.
  */
  subnet?: ApiEntityReference;
  /**
   * Specifies the primary IP Configuration in case the network interface has more than one IP
   * Configuration.
  */
  primary?: boolean;
  /**
   * The publicIPAddressConfiguration.
  */
  publicIPAddressConfiguration?: VirtualMachineScaleSetUpdatePublicIPAddressConfiguration;
  /**
   * Available from Api-Version 2017-03-30 onwards, it represents whether the specific
   * ipconfiguration is IPv4 or IPv6. Default is taken as IPv4.  Possible values are: 'IPv4' and
   * 'IPv6'. Possible values include: 'IPv4', 'IPv6'
  */
  privateIPAddressVersion?: string;
  /**
   * The application gateway backend address pools.
  */
  applicationGatewayBackendAddressPools?: SubResource[];
  /**
   * Specifies an array of references to application security group.
  */
  applicationSecurityGroups?: SubResource[];
  /**
   * The load balancer backend address pools.
  */
  loadBalancerBackendAddressPools?: SubResource[];
  /**
   * The load balancer inbound nat pools.
  */
  loadBalancerInboundNatPools?: SubResource[];
}

/**
 * Describes a virtual machines scale sets network configuration's DNS settings.
*/
export interface VirtualMachineScaleSetNetworkConfigurationDnsSettings {
  /**
   * List of DNS servers IP addresses
  */
  dnsServers?: string[];
}

/**
 * Describes a virtual machine scale set network profile's network configurations.
*/
export interface VirtualMachineScaleSetNetworkConfiguration extends SubResource {
  /**
   * The network configuration name.
  */
  name: string;
  /**
   * Specifies the primary network interface in case the virtual machine has more than 1 network
   * interface.
  */
  primary?: boolean;
  /**
   * Specifies whether the network interface is accelerated networking-enabled.
  */
  enableAcceleratedNetworking?: boolean;
  /**
   * The network security group.
  */
  networkSecurityGroup?: SubResource;
  /**
   * The dns settings to be applied on the network interfaces.
  */
  dnsSettings?: VirtualMachineScaleSetNetworkConfigurationDnsSettings;
  /**
   * Specifies the IP configurations of the network interface.
  */
  ipConfigurations: VirtualMachineScaleSetIPConfiguration[];
  /**
   * Whether IP forwarding enabled on this NIC.
  */
  enableIPForwarding?: boolean;
}

/**
 * Describes a virtual machine scale set network profile's network configurations.
*/
export interface VirtualMachineScaleSetUpdateNetworkConfiguration extends SubResource {
  /**
   * The network configuration name.
  */
  name?: string;
  /**
   * Whether this is a primary NIC on a virtual machine.
  */
  primary?: boolean;
  /**
   * Specifies whether the network interface is accelerated networking-enabled.
  */
  enableAcceleratedNetworking?: boolean;
  /**
   * The network security group.
  */
  networkSecurityGroup?: SubResource;
  /**
   * The dns settings to be applied on the network interfaces.
  */
  dnsSettings?: VirtualMachineScaleSetNetworkConfigurationDnsSettings;
  /**
   * The virtual machine scale set IP Configuration.
  */
  ipConfigurations?: VirtualMachineScaleSetUpdateIPConfiguration[];
  /**
   * Whether IP forwarding enabled on this NIC.
  */
  enableIPForwarding?: boolean;
}

/**
 * Describes a virtual machine scale set network profile.
*/
export interface VirtualMachineScaleSetNetworkProfile {
  /**
   * A reference to a load balancer probe used to determine the health of an instance in the
   * virtual machine scale set. The reference will be in the form:
   * '/subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/Microsoft.Network/loadBalancers/{loadBalancerName}/probes/{probeName}'.
  */
  healthProbe?: ApiEntityReference;
  /**
   * The list of network configurations.
  */
  networkInterfaceConfigurations?: VirtualMachineScaleSetNetworkConfiguration[];
}

/**
 * Describes a virtual machine scale set network profile.
*/
export interface VirtualMachineScaleSetUpdateNetworkProfile {
  /**
   * The list of network configurations.
  */
  networkInterfaceConfigurations?: VirtualMachineScaleSetUpdateNetworkConfiguration[];
}

export interface SubResourceReadOnly extends BaseResource {
  /**
   * Resource Id
  */
  readonly id?: string;
}

/**
 * Describes a Virtual Machine Scale Set Extension.
*/
export interface VirtualMachineScaleSetExtension extends SubResourceReadOnly {
  /**
   * The name of the extension.
  */
  name?: string;
  /**
   * If a value is provided and is different from the previous value, the extension handler will be
   * forced to update even if the extension configuration has not changed.
  */
  forceUpdateTag?: string;
  /**
   * The name of the extension handler publisher.
  */
  publisher?: string;
  /**
   * Specifies the type of the extension; an example is "CustomScriptExtension".
  */
  type?: string;
  /**
   * Specifies the version of the script handler.
  */
  typeHandlerVersion?: string;
  /**
   * Indicates whether the extension should use a newer minor version if one is available at
   * deployment time. Once deployed, however, the extension will not upgrade minor versions unless
   * redeployed, even with this property set to true.
  */
  autoUpgradeMinorVersion?: boolean;
  /**
   * Json formatted public settings for the extension.
  */
  settings?: any;
  /**
   * The extension can contain either protectedSettings or protectedSettingsFromKeyVault or no
   * protected settings at all.
  */
  protectedSettings?: any;
  /**
   * The provisioning state, which only appears in the response.
  */
  readonly provisioningState?: string;
  /**
   * Collection of extension names after which this extension needs to be provisioned.
  */
  provisionAfterExtensions?: string[];
}

/**
 * Describes a virtual machine scale set extension profile.
*/
export interface VirtualMachineScaleSetExtensionProfile {
  /**
   * The virtual machine scale set child extension resources.
  */
  extensions?: VirtualMachineScaleSetExtension[];
}

/**
 * Describes a virtual machine scale set virtual machine profile.
*/
export interface VirtualMachineScaleSetVMProfile {
  /**
   * Specifies the operating system settings for the virtual machines in the scale set.
  */
  osProfile?: VirtualMachineScaleSetOSProfile;
  /**
   * Specifies the storage settings for the virtual machine disks.
  */
  storageProfile?: VirtualMachineScaleSetStorageProfile;
  /**
   * Specifies additional capabilities enabled or disabled on the virtual machine in the scale set.
   * For instance: whether the virtual machine has the capability to support attaching managed data
   * disks with UltraSSD_LRS storage account type.
  */
  additionalCapabilities?: AdditionalCapabilities;
  /**
   * Specifies properties of the network interfaces of the virtual machines in the scale set.
  */
  networkProfile?: VirtualMachineScaleSetNetworkProfile;
  /**
   * Specifies the boot diagnostic settings state. <br><br>Minimum api-version: 2015-06-15.
  */
  diagnosticsProfile?: DiagnosticsProfile;
  /**
   * Specifies a collection of settings for extensions installed on virtual machines in the scale
   * set.
  */
  extensionProfile?: VirtualMachineScaleSetExtensionProfile;
  /**
   * Specifies that the image or disk that is being used was licensed on-premises. This element is
   * only used for images that contain the Windows Server operating system. <br><br> Possible
   * values are: <br><br> Windows_Client <br><br> Windows_Server <br><br> If this element is
   * included in a request for an update, the value must match the initial value. This value cannot
   * be updated. <br><br> For more information, see [Azure Hybrid Use Benefit for Windows
   * Server](https://docs.microsoft.com/azure/virtual-machines/virtual-machines-windows-hybrid-use-benefit-licensing?toc=%2fazure%2fvirtual-machines%2fwindows%2ftoc.json)
   * <br><br> Minimum api-version: 2015-06-15
  */
  licenseType?: string;
  /**
   * Specifies the priority for the virtual machines in the scale set. <br><br>Minimum api-version:
   * 2017-10-30-preview. Possible values include: 'Regular', 'Low'
  */
  priority?: string;
  /**
   * Specifies the eviction policy for virtual machines in a low priority scale set.
   * <br><br>Minimum api-version: 2017-10-30-preview. Possible values include: 'Deallocate',
   * 'Delete'
  */
  evictionPolicy?: string;
}

/**
 * Describes a virtual machine scale set virtual machine profile.
*/
export interface VirtualMachineScaleSetUpdateVMProfile {
  /**
   * The virtual machine scale set OS profile.
  */
  osProfile?: VirtualMachineScaleSetUpdateOSProfile;
  /**
   * The virtual machine scale set storage profile.
  */
  storageProfile?: VirtualMachineScaleSetUpdateStorageProfile;
  /**
   * The virtual machine scale set network profile.
  */
  networkProfile?: VirtualMachineScaleSetUpdateNetworkProfile;
  /**
   * The virtual machine scale set diagnostics profile.
  */
  diagnosticsProfile?: DiagnosticsProfile;
  /**
   * The virtual machine scale set extension profile.
  */
  extensionProfile?: VirtualMachineScaleSetExtensionProfile;
  /**
   * The license type, which is for bring your own license scenario.
  */
  licenseType?: string;
}

/**
 * Describes a Virtual Machine Scale Set.
*/
export interface VirtualMachineScaleSet extends Resource {
  /**
   * The virtual machine scale set sku.
  */
  sku?: Sku;
  /**
   * Specifies information about the marketplace image used to create the virtual machine. This
   * element is only used for marketplace images. Before you can use a marketplace image from an
   * API, you must enable the image for programmatic use.  In the Azure portal, find the
   * marketplace image that you want to use and then click **Want to deploy programmatically, Get
   * Started ->**. Enter any required information and then click **Save**.
  */
  plan?: Plan;
  /**
   * The upgrade policy.
  */
  upgradePolicy?: UpgradePolicy;
  /**
   * The virtual machine profile.
  */
  virtualMachineProfile?: VirtualMachineScaleSetVMProfile;
  /**
   * The provisioning state, which only appears in the response.
  */
  readonly provisioningState?: string;
  /**
   * Specifies whether the Virtual Machine Scale Set should be overprovisioned.
  */
  overprovision?: boolean;
  /**
   * When Overprovision is enabled, extensions are launched only on the requested number of VMs
   * which are finally kept. This property will hence ensure that the extensions do not run on the
   * extra overprovisioned VMs.
  */
  doNotRunExtensionsOnOverprovisionedVMs?: boolean;
  /**
   * Specifies the ID which uniquely identifies a Virtual Machine Scale Set.
  */
  readonly uniqueId?: string;
  /**
   * When true this limits the scale set to a single placement group, of max size 100 virtual
   * machines.
  */
  singlePlacementGroup?: boolean;
  /**
   * Whether to force strictly even Virtual Machine distribution cross x-zones in case there is
   * zone outage.
  */
  zoneBalance?: boolean;
  /**
   * Fault Domain count for each placement group.
  */
  platformFaultDomainCount?: number;
  /**
   * The identity of the virtual machine scale set, if configured.
  */
  identity?: VirtualMachineScaleSetIdentity;
  /**
   * The virtual machine scale set zones.
  */
  zones?: string[];
}

/**
 * Describes a Virtual Machine Scale Set VM Reimage Parameters.
*/
export interface VirtualMachineScaleSetVMReimageParameters extends VirtualMachineReimageParameters
{
}

/**
 * Describes a Virtual Machine Scale Set VM Reimage Parameters.
*/
export interface VirtualMachineScaleSetReimageParameters extends
VirtualMachineScaleSetVMReimageParameters {
  /**
   * The virtual machine scale set instance ids. Omitting the virtual machine scale set instance
   * ids will result in the operation being performed on all virtual machines in the virtual
   * machine scale set.
  */
  instanceIds?: string[];
}

/**
 * Describes a Virtual Machine Scale Set.
*/
export interface VirtualMachineScaleSetUpdate extends UpdateResource {
  /**
   * The virtual machine scale set sku.
  */
  sku?: Sku;
  /**
   * The purchase plan when deploying a virtual machine scale set from VM Marketplace images.
  */
  plan?: Plan;
  /**
   * The upgrade policy.
  */
  upgradePolicy?: UpgradePolicy;
  /**
   * The virtual machine profile.
  */
  virtualMachineProfile?: VirtualMachineScaleSetUpdateVMProfile;
  /**
   * Specifies whether the Virtual Machine Scale Set should be overprovisioned.
  */
  overprovision?: boolean;
  /**
   * When true this limits the scale set to a single placement group, of max size 100 virtual
   * machines.
  */
  singlePlacementGroup?: boolean;
  /**
   * The identity of the virtual machine scale set, if configured.
  */
  identity?: VirtualMachineScaleSetIdentity;
}

/**
 * Specifies a list of virtual machine instance IDs from the VM scale set.
*/
export interface VirtualMachineScaleSetVMInstanceIDs {
  /**
   * The virtual machine scale set instance ids. Omitting the virtual machine scale set instance
   * ids will result in the operation being performed on all virtual machines in the virtual
   * machine scale set.
  */
  instanceIds?: string[];
}

/**
 * Specifies a list of virtual machine instance IDs from the VM scale set.
*/
export interface VirtualMachineScaleSetVMInstanceRequiredIDs {
  /**
   * The virtual machine scale set instance ids.
  */
  instanceIds: string[];
}

/**
 * The status code and count of the virtual machine scale set instance view status summary.
*/
export interface VirtualMachineStatusCodeCount {
  /**
   * The instance view status code.
  */
  readonly code?: string;
  /**
   * The number of instances having a particular status code.
  */
  readonly count?: number;
}

/**
 * Instance view statuses summary for virtual machines of a virtual machine scale set.
*/
export interface VirtualMachineScaleSetInstanceViewStatusesSummary {
  /**
   * The extensions information.
  */
  readonly statusesSummary?: VirtualMachineStatusCodeCount[];
}

/**
 * Extensions summary for virtual machines of a virtual machine scale set.
*/
export interface VirtualMachineScaleSetVMExtensionsSummary {
  /**
   * The extension name.
  */
  readonly name?: string;
  /**
   * The extensions information.
  */
  readonly statusesSummary?: VirtualMachineStatusCodeCount[];
}

/**
 * The instance view of a virtual machine scale set.
*/
export interface VirtualMachineScaleSetInstanceView {
  /**
   * The instance view status summary for the virtual machine scale set.
  */
  readonly virtualMachine?: VirtualMachineScaleSetInstanceViewStatusesSummary;
  /**
   * The extensions information.
  */
  readonly extensions?: VirtualMachineScaleSetVMExtensionsSummary[];
  /**
   * The resource status information.
  */
  statuses?: InstanceViewStatus[];
}

/**
 * Describes scaling information of a sku.
*/
export interface VirtualMachineScaleSetSkuCapacity {
  /**
   * The minimum capacity.
  */
  readonly minimum?: number;
  /**
   * The maximum capacity that can be set.
  */
  readonly maximum?: number;
  /**
   * The default capacity.
  */
  readonly defaultCapacity?: number;
  /**
   * The scale type applicable to the sku. Possible values include: 'Automatic', 'None'
  */
  readonly scaleType?: string;
}

/**
 * Describes an available virtual machine scale set sku.
*/
export interface VirtualMachineScaleSetSku {
  /**
   * The type of resource the sku applies to.
  */
  readonly resourceType?: string;
  /**
   * The Sku.
  */
  readonly sku?: Sku;
  /**
   * Specifies the number of virtual machines in the scale set.
  */
  readonly capacity?: VirtualMachineScaleSetSkuCapacity;
}

/**
 * Api error base.
*/
export interface ApiErrorBase {
  /**
   * The error code.
  */
  code?: string;
  /**
   * The target of the particular error.
  */
  target?: string;
  /**
   * The error message.
  */
  message?: string;
}

/**
 * Inner error details.
*/
export interface InnerError {
  /**
   * The exception type.
  */
  exceptiontype?: string;
  /**
   * The internal error message or exception dump.
  */
  errordetail?: string;
}

/**
 * Api error.
*/
export interface ApiError {
  /**
   * The Api error details
  */
  details?: ApiErrorBase[];
  /**
   * The Api inner error
  */
  innererror?: InnerError;
  /**
   * The error code.
  */
  code?: string;
  /**
   * The target of the particular error.
  */
  target?: string;
  /**
   * The error message.
  */
  message?: string;
}

/**
 * Information about rollback on failed VM instances after a OS Upgrade operation.
*/
export interface RollbackStatusInfo {
  /**
   * The number of instances which have been successfully rolled back.
  */
  readonly successfullyRolledbackInstanceCount?: number;
  /**
   * The number of instances which failed to rollback.
  */
  readonly failedRolledbackInstanceCount?: number;
  /**
   * Error details if OS rollback failed.
  */
  readonly rollbackError?: ApiError;
}

/**
 * Information about the current running state of the overall upgrade.
*/
export interface UpgradeOperationHistoryStatus {
  /**
   * Code indicating the current status of the upgrade. Possible values include: 'RollingForward',
   * 'Cancelled', 'Completed', 'Faulted'
  */
  readonly code?: string;
  /**
   * Start time of the upgrade.
  */
  readonly startTime?: Date;
  /**
   * End time of the upgrade.
  */
  readonly endTime?: Date;
}

/**
 * Information about the number of virtual machine instances in each upgrade state.
*/
export interface RollingUpgradeProgressInfo {
  /**
   * The number of instances that have been successfully upgraded.
  */
  readonly successfulInstanceCount?: number;
  /**
   * The number of instances that have failed to be upgraded successfully.
  */
  readonly failedInstanceCount?: number;
  /**
   * The number of instances that are currently being upgraded.
  */
  readonly inProgressInstanceCount?: number;
  /**
   * The number of instances that have not yet begun to be upgraded.
  */
  readonly pendingInstanceCount?: number;
}

/**
 * Describes each OS upgrade on the Virtual Machine Scale Set.
*/
export interface UpgradeOperationHistoricalStatusInfoProperties {
  /**
   * Information about the overall status of the upgrade operation.
  */
  readonly runningStatus?: UpgradeOperationHistoryStatus;
  /**
   * Counts of the VMs in each state.
  */
  readonly progress?: RollingUpgradeProgressInfo;
  /**
   * Error Details for this upgrade if there are any.
  */
  readonly error?: ApiError;
  /**
   * Invoker of the Upgrade Operation. Possible values include: 'Unknown', 'User', 'Platform'
  */
  readonly startedBy?: string;
  /**
   * Image Reference details
  */
  readonly targetImageReference?: ImageReference;
  /**
   * Information about OS rollback if performed
  */
  readonly rollbackInfo?: RollbackStatusInfo;
}

/**
 * Virtual Machine Scale Set OS Upgrade History operation response.
*/
export interface UpgradeOperationHistoricalStatusInfo {
  /**
   * Information about the properties of the upgrade operation.
  */
  readonly properties?: UpgradeOperationHistoricalStatusInfoProperties;
  /**
   * Resource type
  */
  readonly type?: string;
  /**
   * Resource location
  */
  readonly location?: string;
}

/**
 * The health status of the VM.
*/
export interface VirtualMachineHealthStatus {
  /**
   * The health status information for the VM.
  */
  readonly status?: InstanceViewStatus;
}

/**
 * The instance view of a virtual machine scale set VM.
*/
export interface VirtualMachineScaleSetVMInstanceView {
  /**
   * The Update Domain count.
  */
  platformUpdateDomain?: number;
  /**
   * The Fault Domain count.
  */
  platformFaultDomain?: number;
  /**
   * The Remote desktop certificate thumbprint.
  */
  rdpThumbPrint?: string;
  /**
   * The VM Agent running on the virtual machine.
  */
  vmAgent?: VirtualMachineAgentInstanceView;
  /**
   * The Maintenance Operation status on the virtual machine.
  */
  maintenanceRedeployStatus?: MaintenanceRedeployStatus;
  /**
   * The disks information.
  */
  disks?: DiskInstanceView[];
  /**
   * The extensions information.
  */
  extensions?: VirtualMachineExtensionInstanceView[];
  /**
   * The health status for the VM.
  */
  readonly vmHealth?: VirtualMachineHealthStatus;
  /**
   * Boot Diagnostics is a debugging feature which allows you to view Console Output and Screenshot
   * to diagnose VM status. <br><br> You can easily view the output of your console log. <br><br>
   * Azure also enables you to see a screenshot of the VM from the hypervisor.
  */
  bootDiagnostics?: BootDiagnosticsInstanceView;
  /**
   * The resource status information.
  */
  statuses?: InstanceViewStatus[];
  /**
   * The placement group in which the VM is running. If the VM is deallocated it will not have a
   * placementGroupId.
  */
  placementGroupId?: string;
}

/**
 * Describes a virtual machine scale set VM network profile.
*/
export interface VirtualMachineScaleSetVMNetworkProfileConfiguration {
  /**
   * The list of network configurations.
  */
  networkInterfaceConfigurations?: VirtualMachineScaleSetNetworkConfiguration[];
}

/**
 * The protection policy of a virtual machine scale set VM.
*/
export interface VirtualMachineScaleSetVMProtectionPolicy {
  /**
   * Indicates that the virtual machine scale set VM shouldn't be considered for deletion during a
   * scale-in operation.
  */
  protectFromScaleIn?: boolean;
  /**
   * Indicates that model updates or actions (including scale-in) initiated on the virtual machine
   * scale set should not be applied to the virtual machine scale set VM.
  */
  protectFromScaleSetActions?: boolean;
}

/**
 * Describes a virtual machine scale set virtual machine.
*/
export interface VirtualMachineScaleSetVM extends Resource {
  /**
   * The virtual machine instance ID.
  */
  readonly instanceId?: string;
  /**
   * The virtual machine SKU.
  */
  readonly sku?: Sku;
  /**
   * Specifies whether the latest model has been applied to the virtual machine.
  */
  readonly latestModelApplied?: boolean;
  /**
   * Azure VM unique ID.
  */
  readonly vmId?: string;
  /**
   * The virtual machine instance view.
  */
  readonly instanceView?: VirtualMachineScaleSetVMInstanceView;
  /**
   * Specifies the hardware settings for the virtual machine.
  */
  hardwareProfile?: HardwareProfile;
  /**
   * Specifies the storage settings for the virtual machine disks.
  */
  storageProfile?: StorageProfile;
  /**
   * Specifies additional capabilities enabled or disabled on the virtual machine in the scale set.
   * For instance: whether the virtual machine has the capability to support attaching managed data
   * disks with UltraSSD_LRS storage account type.
  */
  additionalCapabilities?: AdditionalCapabilities;
  /**
   * Specifies the operating system settings for the virtual machine.
  */
  osProfile?: OSProfile;
  /**
   * Specifies the network interfaces of the virtual machine.
  */
  networkProfile?: NetworkProfile;
  /**
   * Specifies the network profile configuration of the virtual machine.
  */
  networkProfileConfiguration?: VirtualMachineScaleSetVMNetworkProfileConfiguration;
  /**
   * Specifies the boot diagnostic settings state. <br><br>Minimum api-version: 2015-06-15.
  */
  diagnosticsProfile?: DiagnosticsProfile;
  /**
   * Specifies information about the availability set that the virtual machine should be assigned
   * to. Virtual machines specified in the same availability set are allocated to different nodes
   * to maximize availability. For more information about availability sets, see [Manage the
   * availability of virtual
   * machines](https://docs.microsoft.com/azure/virtual-machines/virtual-machines-windows-manage-availability?toc=%2fazure%2fvirtual-machines%2fwindows%2ftoc.json).
   * <br><br> For more information on Azure planned maintenance, see [Planned maintenance for
   * virtual machines in
   * Azure](https://docs.microsoft.com/azure/virtual-machines/virtual-machines-windows-planned-maintenance?toc=%2fazure%2fvirtual-machines%2fwindows%2ftoc.json)
   * <br><br> Currently, a VM can only be added to availability set at creation time. An existing
   * VM cannot be added to an availability set.
  */
  availabilitySet?: SubResource;
  /**
   * The provisioning state, which only appears in the response.
  */
  readonly provisioningState?: string;
  /**
   * Specifies that the image or disk that is being used was licensed on-premises. This element is
   * only used for images that contain the Windows Server operating system. <br><br> Possible
   * values are: <br><br> Windows_Client <br><br> Windows_Server <br><br> If this element is
   * included in a request for an update, the value must match the initial value. This value cannot
   * be updated. <br><br> For more information, see [Azure Hybrid Use Benefit for Windows
   * Server](https://docs.microsoft.com/azure/virtual-machines/virtual-machines-windows-hybrid-use-benefit-licensing?toc=%2fazure%2fvirtual-machines%2fwindows%2ftoc.json)
   * <br><br> Minimum api-version: 2015-06-15
  */
  licenseType?: string;
  /**
   * Specifies whether the model applied to the virtual machine is the model of the virtual machine
   * scale set or the customized model for the virtual machine.
  */
  readonly modelDefinitionApplied?: string;
  /**
   * Specifies the protection policy of the virtual machine.
  */
  protectionPolicy?: VirtualMachineScaleSetVMProtectionPolicy;
  /**
   * Specifies information about the marketplace image used to create the virtual machine. This
   * element is only used for marketplace images. Before you can use a marketplace image from an
   * API, you must enable the image for programmatic use.  In the Azure portal, find the
   * marketplace image that you want to use and then click **Want to deploy programmatically, Get
   * Started ->**. Enter any required information and then click **Save**.
  */
  plan?: Plan;
  /**
   * The virtual machine child extension resources.
  */
  readonly resources?: VirtualMachineExtension[];
  /**
   * The virtual machine zones.
  */
  readonly zones?: string[];
}

/**
 * Information about the current running state of the overall upgrade.
*/
export interface RollingUpgradeRunningStatus {
  /**
   * Code indicating the current status of the upgrade. Possible values include: 'RollingForward',
   * 'Cancelled', 'Completed', 'Faulted'
  */
  readonly code?: string;
  /**
   * Start time of the upgrade.
  */
  readonly startTime?: Date;
  /**
   * The last action performed on the rolling upgrade. Possible values include: 'Start', 'Cancel'
  */
  readonly lastAction?: string;
  /**
   * Last action time of the upgrade.
  */
  readonly lastActionTime?: Date;
}

/**
 * The status of the latest virtual machine scale set rolling upgrade.
*/
export interface RollingUpgradeStatusInfo extends Resource {
  /**
   * The rolling upgrade policies applied for this upgrade.
  */
  readonly policy?: RollingUpgradePolicy;
  /**
   * Information about the current running state of the overall upgrade.
  */
  readonly runningStatus?: RollingUpgradeRunningStatus;
  /**
   * Information about the number of virtual machine instances in each upgrade state.
  */
  readonly progress?: RollingUpgradeProgressInfo;
  /**
   * Error details for this upgrade, if there are any.
  */
  readonly error?: ApiError;
}

/**
 * Response after calling a manual recovery walk
*/
export interface RecoveryWalkResponse {
  /**
   * Whether the recovery walk was performed
  */
  readonly walkPerformed?: boolean;
  /**
   * The next update domain that needs to be walked. Null means walk spanning all update domains
   * has been completed
  */
  readonly nextPlatformUpdateDomain?: number;
}

/**
 * Api input base class for LogAnalytics Api.
*/
export interface LogAnalyticsInputBase {
  /**
   * SAS Uri of the logging blob container to which LogAnalytics Api writes output logs to.
  */
  blobContainerSasUri: string;
  /**
   * From time of the query
  */
  fromTime: Date;
  /**
   * To time of the query
  */
  toTime: Date;
  /**
   * Group query result by Throttle Policy applied.
  */
  groupByThrottlePolicy?: boolean;
  /**
   * Group query result by Operation Name.
  */
  groupByOperationName?: boolean;
  /**
   * Group query result by Resource Name.
  */
  groupByResourceName?: boolean;
}

/**
 * Api request input for LogAnalytics getRequestRateByInterval Api.
*/
export interface RequestRateByIntervalInput extends LogAnalyticsInputBase {
  /**
   * Interval value in minutes used to create LogAnalytics call rate logs. Possible values include:
   * 'ThreeMins', 'FiveMins', 'ThirtyMins', 'SixtyMins'
  */
  intervalLength: string;
}

/**
 * Api request input for LogAnalytics getThrottledRequests Api.
*/
export interface ThrottledRequestsInput extends LogAnalyticsInputBase {
}

/**
 * LogAnalytics output properties
*/
export interface LogAnalyticsOutput {
  /**
   * Output file Uri path to blob container.
  */
  readonly output?: string;
}

/**
 * LogAnalytics operation status response
*/
export interface LogAnalyticsOperationResult {
  /**
   * LogAnalyticsOutput
  */
  readonly properties?: LogAnalyticsOutput;
}

export interface VMScaleSetConvertToSinglePlacementGroupInput {
  /**
   * Id of the placement group in which you want future virtual machine instances to be placed. To
   * query placement group Id, please use Virtual Machine Scale Set VMs - Get API. If not provided,
   * the platform will choose one with maximum number of virtual machine instances.
  */
  activePlacementGroupId?: string;
}

/**
 * Describes the properties of a run command parameter.
*/
export interface RunCommandInputParameter {
  /**
   * The run command parameter name.
  */
  name: string;
  /**
   * The run command parameter value.
  */
  value: string;
}

/**
 * Capture Virtual Machine parameters.
*/
export interface RunCommandInput {
  /**
   * The run command id.
  */
  commandId: string;
  /**
   * Optional. The script to be executed.  When this value is given, the given script will override
   * the default script of the command.
  */
  script?: string[];
  /**
   * The run command parameters.
  */
  parameters?: RunCommandInputParameter[];
}

/**
 * Describes the properties of a run command parameter.
*/
export interface RunCommandParameterDefinition {
  /**
   * The run command parameter name.
  */
  name: string;
  /**
   * The run command parameter type.
  */
  type: string;
  /**
   * The run command parameter default value.
  */
  defaultValue?: string;
  /**
   * The run command parameter required.
  */
  required?: boolean;
}

/**
 * Describes the properties of a Run Command metadata.
*/
export interface RunCommandDocumentBase {
  /**
   * The VM run command schema.
  */
  schema: string;
  /**
   * The VM run command id.
  */
  id: string;
  /**
   * The Operating System type. Possible values include: 'Windows', 'Linux'
  */
  osType: string;
  /**
   * The VM run command label.
  */
  label: string;
  /**
   * The VM run command description.
  */
  description: string;
}

/**
 * Describes the properties of a Run Command.
*/
export interface RunCommandDocument extends RunCommandDocumentBase {
  /**
   * The script to be executed.
  */
  script: string[];
  /**
   * The parameters used by the script.
  */
  parameters?: RunCommandParameterDefinition[];
}

export interface RunCommandResult {
  /**
   * Run command operation response.
  */
  value?: InstanceViewStatus[];
}

/**
 * Describes scaling information of a SKU.
*/
export interface ResourceSkuCapacity {
  /**
   * The minimum capacity.
  */
  readonly minimum?: number;
  /**
   * The maximum capacity that can be set.
  */
  readonly maximum?: number;
  /**
   * The default capacity.
  */
  readonly default?: number;
  /**
   * The scale type applicable to the sku. Possible values include: 'Automatic', 'Manual', 'None'
  */
  readonly scaleType?: string;
}

/**
 * Describes metadata for retrieving price info.
*/
export interface ResourceSkuCosts {
  /**
   * Used for querying price from commerce.
  */
  readonly meterID?: string;
  /**
   * The multiplier is needed to extend the base metered cost.
  */
  readonly quantity?: number;
  /**
   * An invariant to show the extended unit.
  */
  readonly extendedUnit?: string;
}

/**
 * Describes The SKU capabilities object.
*/
export interface ResourceSkuCapabilities {
  /**
   * An invariant to describe the feature.
  */
  readonly name?: string;
  /**
   * An invariant if the feature is measured by quantity.
  */
  readonly value?: string;
}

export interface ResourceSkuRestrictionInfo {
  /**
   * Locations where the SKU is restricted
  */
  readonly locations?: string[];
  /**
   * List of availability zones where the SKU is restricted.
  */
  readonly zones?: string[];
}

/**
 * Describes scaling information of a SKU.
*/
export interface ResourceSkuRestrictions {
  /**
   * The type of restrictions. Possible values include: 'Location', 'Zone'
  */
  readonly type?: string;
  /**
   * The value of restrictions. If the restriction type is set to location. This would be different
   * locations where the SKU is restricted.
  */
  readonly values?: string[];
  /**
   * The information about the restriction where the SKU cannot be used.
  */
  readonly restrictionInfo?: ResourceSkuRestrictionInfo;
  /**
   * The reason for restriction. Possible values include: 'QuotaId', 'NotAvailableForSubscription'
  */
  readonly reasonCode?: string;
}

export interface ResourceSkuLocationInfo {
  /**
   * Location of the SKU
  */
  readonly location?: string;
  /**
   * List of availability zones where the SKU is supported.
  */
  readonly zones?: string[];
}

/**
 * Describes an available Compute SKU.
*/
export interface ResourceSku {
  /**
   * The type of resource the SKU applies to.
  */
  readonly resourceType?: string;
  /**
   * The name of SKU.
  */
  readonly name?: string;
  /**
   * Specifies the tier of virtual machines in a scale set.<br /><br /> Possible Values:<br /><br
   * /> **Standard**<br /><br /> **Basic**
  */
  readonly tier?: string;
  /**
   * The Size of the SKU.
  */
  readonly size?: string;
  /**
   * The Family of this particular SKU.
  */
  readonly family?: string;
  /**
   * The Kind of resources that are supported in this SKU.
  */
  readonly kind?: string;
  /**
   * Specifies the number of virtual machines in the scale set.
  */
  readonly capacity?: ResourceSkuCapacity;
  /**
   * The set of locations that the SKU is available.
  */
  readonly locations?: string[];
  /**
   * A list of locations and availability zones in those locations where the SKU is available.
  */
  readonly locationInfo?: ResourceSkuLocationInfo[];
  /**
   * The api versions that support this SKU.
  */
  readonly apiVersions?: string[];
  /**
   * Metadata for retrieving price info.
  */
  readonly costs?: ResourceSkuCosts[];
  /**
   * A name value pair to describe the capability.
  */
  readonly capabilities?: ResourceSkuCapabilities[];
  /**
   * The restrictions because of which SKU cannot be used. This is empty if there are no
   * restrictions.
  */
  readonly restrictions?: ResourceSkuRestrictions[];
}

/**
 * The disks sku name. Can be Standard_LRS, Premium_LRS, StandardSSD_LRS, or UltraSSD_LRS.
*/
export interface DiskSku {
  /**
   * The sku name. Possible values include: 'Standard_LRS', 'Premium_LRS', 'StandardSSD_LRS',
   * 'UltraSSD_LRS'
  */
  name?: string;
  /**
   * The sku tier.
  */
  readonly tier?: string;
}

/**
 * The source image used for creating the disk.
*/
export interface ImageDiskReference {
  /**
   * A relative uri containing either a Platform Image Repository or user image reference.
  */
  id: string;
  /**
   * If the disk is created from an image's data disk, this is an index that indicates which of the
   * data disks in the image to use. For OS disks, this field is null.
  */
  lun?: number;
}

/**
 * Data used when creating a disk.
*/
export interface CreationData {
  /**
   * This enumerates the possible sources of a disk's creation. Possible values include: 'Empty',
   * 'Attach', 'FromImage', 'Import', 'Copy', 'Restore', 'Upload'
  */
  createOption: string;
  /**
   * If createOption is Import, the Azure Resource Manager identifier of the storage account
   * containing the blob to import as a disk. Required only if the blob is in a different
   * subscription
  */
  storageAccountId?: string;
  /**
   * Disk source information.
  */
  imageReference?: ImageDiskReference;
  /**
   * If createOption is Import, this is the URI of a blob to be imported into a managed disk.
  */
  sourceUri?: string;
  /**
   * If createOption is Copy, this is the ARM id of the source snapshot or disk.
  */
  sourceResourceId?: string;
}

/**
 * The vault id is an Azure Resource Manager Resource id in the form
 * /subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/Microsoft.KeyVault/vaults/{vaultName}
*/
export interface SourceVault {
  /**
   * Resource Id
  */
  id?: string;
}

/**
 * Key Vault Secret Url and vault id of the encryption key
*/
export interface KeyVaultAndSecretReference {
  /**
   * Resource id of the KeyVault containing the key or secret
  */
  sourceVault: SourceVault;
  /**
   * Url pointing to a key or secret in KeyVault
  */
  secretUrl: string;
}

/**
 * Key Vault Key Url and vault id of KeK, KeK is optional and when provided is used to unwrap the
 * encryptionKey
*/
export interface KeyVaultAndKeyReference {
  /**
   * Resource id of the KeyVault containing the key or secret
  */
  sourceVault: SourceVault;
  /**
   * Url pointing to a key or secret in KeyVault
  */
  keyUrl: string;
}

/**
 * Encryption settings for one disk volume.
*/
export interface EncryptionSettingsElement {
  /**
   * Key Vault Secret Url and vault id of the disk encryption key
  */
  diskEncryptionKey?: KeyVaultAndSecretReference;
  /**
   * Key Vault Key Url and vault id of the key encryption key. KeyEncryptionKey is optional and
   * when provided is used to unwrap the disk encryption key.
  */
  keyEncryptionKey?: KeyVaultAndKeyReference;
}

/**
 * Encryption settings for disk or snapshot
*/
export interface EncryptionSettingsCollection {
  /**
   * Set this flag to true and provide DiskEncryptionKey and optional KeyEncryptionKey to enable
   * encryption. Set this flag to false and remove DiskEncryptionKey and KeyEncryptionKey to
   * disable encryption. If EncryptionSettings is null in the request object, the existing settings
   * remain unchanged.
  */
  enabled: boolean;
  /**
   * A collection of encryption settings, one for each disk volume.
  */
  encryptionSettings?: EncryptionSettingsElement[];
}

/**
 * Disk resource.
*/
export interface Disk extends Resource {
  /**
   * A relative URI containing the ID of the VM that has the disk attached.
  */
  readonly managedBy?: string;
  sku?: DiskSku;
  /**
   * The Logical zone list for Disk.
  */
  zones?: string[];
  /**
   * The time when the disk was created.
  */
  readonly timeCreated?: Date;
  /**
   * The Operating System type. Possible values include: 'Windows', 'Linux'
  */
  osType?: string;
  /**
   * The hypervisor generation of the Virtual Machine. Applicable to OS disks only. Possible values
   * include: 'V1', 'V2'
  */
  hyperVGeneration?: string;
  /**
   * Disk source information. CreationData information cannot be changed after the disk has been
   * created.
  */
  creationData: CreationData;
  /**
   * If creationData.createOption is Empty, this field is mandatory and it indicates the size of
   * the VHD to create. If this field is present for updates or creation with other options, it
   * indicates a resize. Resizes are only allowed if the disk is not attached to a running VM, and
   * can only increase the disk's size.
  */
  diskSizeGB?: number;
  /**
   * Encryption settings collection used for Azure Disk Encryption, can contain multiple encryption
   * settings per disk or snapshot.
  */
  encryptionSettingsCollection?: EncryptionSettingsCollection;
  /**
   * The disk provisioning state.
  */
  readonly provisioningState?: string;
  /**
   * The number of IOPS allowed for this disk; only settable for UltraSSD disks. One operation can
   * transfer between 4k and 256k bytes.
  */
  diskIOPSReadWrite?: number;
  /**
   * The bandwidth allowed for this disk; only settable for UltraSSD disks. MBps means millions of
   * bytes per second - MB here uses the ISO notation, of powers of 10.
  */
  diskMBpsReadWrite?: number;
  /**
   * The state of the disk. Possible values include: 'Unattached', 'Attached', 'Reserved',
   * 'ActiveSAS', 'ReadyToUpload', 'ActiveUpload'
  */
  readonly diskState?: string;
}

/**
 * Disk update resource.
*/
export interface DiskUpdate {
  /**
   * the Operating System type. Possible values include: 'Windows', 'Linux'
  */
  osType?: string;
  /**
   * If creationData.createOption is Empty, this field is mandatory and it indicates the size of
   * the VHD to create. If this field is present for updates or creation with other options, it
   * indicates a resize. Resizes are only allowed if the disk is not attached to a running VM, and
   * can only increase the disk's size.
  */
  diskSizeGB?: number;
  /**
   * Encryption settings collection used be Azure Disk Encryption, can contain multiple encryption
   * settings per disk or snapshot.
  */
  encryptionSettingsCollection?: EncryptionSettingsCollection;
  /**
   * The number of IOPS allowed for this disk; only settable for UltraSSD disks. One operation can
   * transfer between 4k and 256k bytes.
  */
  diskIOPSReadWrite?: number;
  /**
   * The bandwidth allowed for this disk; only settable for UltraSSD disks. MBps means millions of
   * bytes per second - MB here uses the ISO notation, of powers of 10.
  */
  diskMBpsReadWrite?: number;
  /**
   * Resource tags
  */
  tags?: { [propertyName: string]: string };
  sku?: DiskSku;
}

/**
 * The snapshots sku name. Can be Standard_LRS, Premium_LRS, or Standard_ZRS.
*/
export interface SnapshotSku {
  /**
   * The sku name. Possible values include: 'Standard_LRS', 'Premium_LRS', 'Standard_ZRS'
  */
  name?: string;
  /**
   * The sku tier.
  */
  readonly tier?: string;
}

/**
 * Data used for requesting a SAS.
*/
export interface GrantAccessData {
  /**
   * Possible values include: 'None', 'Read', 'Write'
  */
  access: string;
  /**
   * Time duration in seconds until the SAS access expires.
  */
  durationInSeconds: number;
}

/**
 * A disk access SAS uri.
*/
export interface AccessUri {
  /**
   * A SAS uri for accessing a disk.
  */
  readonly accessSAS?: string;
}

/**
 * Snapshot resource.
*/
export interface Snapshot extends Resource {
  /**
   * Unused. Always Null.
  */
  readonly managedBy?: string;
  sku?: SnapshotSku;
  /**
   * The time when the disk was created.
  */
  readonly timeCreated?: Date;
  /**
   * The Operating System type. Possible values include: 'Windows', 'Linux'
  */
  osType?: string;
  /**
   * The hypervisor generation of the Virtual Machine. Applicable to OS disks only. Possible values
   * include: 'V1', 'V2'
  */
  hyperVGeneration?: string;
  /**
   * Disk source information. CreationData information cannot be changed after the disk has been
   * created.
  */
  creationData: CreationData;
  /**
   * If creationData.createOption is Empty, this field is mandatory and it indicates the size of
   * the VHD to create. If this field is present for updates or creation with other options, it
   * indicates a resize. Resizes are only allowed if the disk is not attached to a running VM, and
   * can only increase the disk's size.
  */
  diskSizeGB?: number;
  /**
   * Encryption settings collection used be Azure Disk Encryption, can contain multiple encryption
   * settings per disk or snapshot.
  */
  encryptionSettingsCollection?: EncryptionSettingsCollection;
  /**
   * The disk provisioning state.
  */
  readonly provisioningState?: string;
}

/**
 * Snapshot update resource.
*/
export interface SnapshotUpdate {
  /**
   * the Operating System type. Possible values include: 'Windows', 'Linux'
  */
  osType?: string;
  /**
   * If creationData.createOption is Empty, this field is mandatory and it indicates the size of
   * the VHD to create. If this field is present for updates or creation with other options, it
   * indicates a resize. Resizes are only allowed if the disk is not attached to a running VM, and
   * can only increase the disk's size.
  */
  diskSizeGB?: number;
  /**
   * Encryption settings collection used be Azure Disk Encryption, can contain multiple encryption
   * settings per disk or snapshot.
  */
  encryptionSettingsCollection?: EncryptionSettingsCollection;
  /**
   * Resource tags
  */
  tags?: { [propertyName: string]: string };
  sku?: SnapshotSku;
}

/**
 * Describes the gallery unique name.
*/
export interface GalleryIdentifier {
  /**
   * The unique name of the Shared Image Gallery. This name is generated automatically by Azure.
  */
  readonly uniqueName?: string;
}

/**
 * Specifies information about the Shared Image Gallery that you want to create or update.
*/
export interface Gallery extends Resource {
  /**
   * The description of this Shared Image Gallery resource. This property is updatable.
  */
  description?: string;
  identifier?: GalleryIdentifier;
  /**
   * @summary The current state of the gallery.
   * @description The provisioning state, which only appears in the response. Possible values
   * include: 'Creating', 'Updating', 'Failed', 'Succeeded', 'Deleting', 'Migrating'
  */
  readonly provisioningState?: string;
}

/**
 * This is the gallery Image Definition identifier.
*/
export interface GalleryImageIdentifier {
  /**
   * The name of the gallery Image Definition publisher.
  */
  publisher: string;
  /**
   * The name of the gallery Image Definition offer.
  */
  offer: string;
  /**
   * The name of the gallery Image Definition SKU.
  */
  sku: string;
}

/**
 * Describes the resource range.
*/
export interface ResourceRange {
  /**
   * The minimum number of the resource.
  */
  min?: number;
  /**
   * The maximum number of the resource.
  */
  max?: number;
}

/**
 * The properties describe the recommended machine configuration for this Image Definition. These
 * properties are updatable.
*/
export interface RecommendedMachineConfiguration {
  vCPUs?: ResourceRange;
  memory?: ResourceRange;
}

/**
 * Describes the disallowed disk types.
*/
export interface Disallowed {
  /**
   * A list of disk types.
  */
  diskTypes?: string[];
}

/**
 * Describes the gallery Image Definition purchase plan. This is used by marketplace images.
*/
export interface ImagePurchasePlan {
  /**
   * The plan ID.
  */
  name?: string;
  /**
   * The publisher ID.
  */
  publisher?: string;
  /**
   * The product ID.
  */
  product?: string;
}

/**
 * Specifies information about the gallery Image Definition that you want to create or update.
*/
export interface GalleryImage extends Resource {
  /**
   * The description of this gallery Image Definition resource. This property is updatable.
  */
  description?: string;
  /**
   * The Eula agreement for the gallery Image Definition.
  */
  eula?: string;
  /**
   * The privacy statement uri.
  */
  privacyStatementUri?: string;
  /**
   * The release note uri.
  */
  releaseNoteUri?: string;
  /**
   * This property allows you to specify the type of the OS that is included in the disk when
   * creating a VM from a managed image. <br><br> Possible values are: <br><br> **Windows**
   * <br><br> **Linux**. Possible values include: 'Windows', 'Linux'
  */
  osType: string;
  /**
   * The allowed values for OS State are 'Generalized'. Possible values include: 'Generalized',
   * 'Specialized'
  */
  osState: string;
  /**
   * The end of life date of the gallery Image Definition. This property can be used for
   * decommissioning purposes. This property is updatable.
  */
  endOfLifeDate?: Date;
  identifier: GalleryImageIdentifier;
  recommended?: RecommendedMachineConfiguration;
  disallowed?: Disallowed;
  purchasePlan?: ImagePurchasePlan;
  /**
   * @summary The current state of the gallery Image Definition.
   * @description The provisioning state, which only appears in the response. Possible values
   * include: 'Creating', 'Updating', 'Failed', 'Succeeded', 'Deleting', 'Migrating'
  */
  readonly provisioningState?: string;
}

/**
 * Describes the basic gallery artifact publishing profile.
*/
export interface GalleryArtifactPublishingProfileBase {
  /**
   * The target regions where the Image Version is going to be replicated to. This property is
   * updatable.
  */
  targetRegions?: TargetRegion[];
  source: GalleryArtifactSource;
}

/**
 * The publishing profile of a gallery Image Version.
*/
export interface GalleryImageVersionPublishingProfile extends GalleryArtifactPublishingProfileBase
{
  /**
   * The number of replicas of the Image Version to be created per region. This property would take
   * effect for a region when regionalReplicaCount is not specified. This property is updatable.
  */
  replicaCount?: number;
  /**
   * If set to true, Virtual Machines deployed from the latest version of the Image Definition
   * won't use this Image Version.
  */
  excludeFromLatest?: boolean;
  /**
   * The timestamp for when the gallery Image Version is published.
  */
  readonly publishedDate?: Date;
  /**
   * The end of life date of the gallery Image Version. This property can be used for
   * decommissioning purposes. This property is updatable.
  */
  endOfLifeDate?: Date;
  /**
   * Specifies the storage account type to be used to store the image. This property is not
   * updatable. Possible values include: 'Standard_LRS', 'Standard_ZRS'
  */
  storageAccountType?: string;
}

/**
 * This is the disk image base class.
*/
export interface GalleryDiskImage {
  /**
   * This property indicates the size of the VHD to be created.
  */
  readonly sizeInGB?: number;
  /**
   * The host caching of the disk. Valid values are 'None', 'ReadOnly', and 'ReadWrite'. Possible
   * values include: 'None', 'ReadOnly', 'ReadWrite'
  */
  readonly hostCaching?: string;
}

/**
 * This is the OS disk image.
*/
export interface GalleryOSDiskImage extends GalleryDiskImage {
}

/**
 * This is the data disk image.
*/
export interface GalleryDataDiskImage extends GalleryDiskImage {
  /**
   * This property specifies the logical unit number of the data disk. This value is used to
   * identify data disks within the Virtual Machine and therefore must be unique for each data disk
   * attached to the Virtual Machine.
  */
  readonly lun?: number;
}

/**
 * This is the storage profile of a gallery Image Version.
*/
export interface GalleryImageVersionStorageProfile {
  readonly osDiskImage?: GalleryOSDiskImage;
  /**
   * A list of data disk images.
  */
  readonly dataDiskImages?: GalleryDataDiskImage[];
}

/**
 * This is the regional replication status.
*/
export interface RegionalReplicationStatus {
  /**
   * The region to which the gallery Image Version is being replicated to.
  */
  readonly region?: string;
  /**
   * This is the regional replication state. Possible values include: 'Unknown', 'Replicating',
   * 'Completed', 'Failed'
  */
  readonly state?: string;
  /**
   * The details of the replication status.
  */
  readonly details?: string;
  /**
   * It indicates progress of the replication job.
  */
  readonly progress?: number;
}

/**
 * This is the replication status of the gallery Image Version.
*/
export interface ReplicationStatus {
  /**
   * This is the aggregated replication status based on all the regional replication status flags.
   * Possible values include: 'Unknown', 'InProgress', 'Completed', 'Failed'
  */
  readonly aggregatedState?: string;
  /**
   * This is a summary of replication status for each region.
  */
  readonly summary?: RegionalReplicationStatus[];
}

/**
 * Specifies information about the gallery Image Version that you want to create or update.
*/
export interface GalleryImageVersion extends Resource {
  publishingProfile: GalleryImageVersionPublishingProfile;
  /**
   * @summary The current state of the gallery Image Version.
   * @description The provisioning state, which only appears in the response. Possible values
   * include: 'Creating', 'Updating', 'Failed', 'Succeeded', 'Deleting', 'Migrating'
  */
  readonly provisioningState?: string;
  readonly storageProfile?: GalleryImageVersionStorageProfile;
  readonly replicationStatus?: ReplicationStatus;
}

/**
 * Describes the target region information.
*/
export interface TargetRegion {
  /**
   * The name of the region.
  */
  name: string;
  /**
   * The number of replicas of the Image Version to be created per region. This property is
   * updatable.
  */
  regionalReplicaCount?: number;
  /**
   * Specifies the storage account type to be used to store the image. This property is not
   * updatable. Possible values include: 'Standard_LRS', 'Standard_ZRS'
  */
  storageAccountType?: string;
}

/**
 * The managed artifact.
*/
export interface ManagedArtifact {
  /**
   * The managed artifact id.
  */
  id: string;
}

/**
 * The source image from which the Image Version is going to be created.
*/
export interface GalleryArtifactSource {
  managedImage: ManagedArtifact;
}

/**
 * Properties to configure a custom container service cluster.
*/
export interface ContainerServiceCustomProfile {
  /**
   * The name of the custom orchestrator to use.
  */
  orchestrator: string;
}

/**
 * Information about a service principal identity for the cluster to use for manipulating Azure
 * APIs.
*/
export interface ContainerServiceServicePrincipalProfile {
  /**
   * The ID for the service principal.
  */
  clientId: string;
  /**
   * The secret password associated with the service principal.
  */
  secret: string;
}

/**
 * Profile for the container service orchestrator.
*/
export interface ContainerServiceOrchestratorProfile {
  /**
   * The orchestrator to use to manage container service cluster resources. Valid values are Swarm,
   * DCOS, and Custom. Possible values include: 'Swarm', 'DCOS', 'Custom', 'Kubernetes'
  */
  orchestratorType: string;
}

/**
 * Profile for the container service master.
*/
export interface ContainerServiceMasterProfile {
  /**
   * Number of masters (VMs) in the container service cluster. Allowed values are 1, 3, and 5. The
   * default value is 1.
  */
  count?: number;
  /**
   * DNS prefix to be used to create the FQDN for master.
  */
  dnsPrefix: string;
  /**
   * FQDN for the master.
  */
  readonly fqdn?: string;
}

/**
 * Profile for the container service agent pool.
*/
export interface ContainerServiceAgentPoolProfile {
  /**
   * Unique name of the agent pool profile in the context of the subscription and resource group.
  */
  name: string;
  /**
   * Number of agents (VMs) to host docker containers. Allowed values must be in the range of 1 to
   * 100 (inclusive). The default value is 1.
  */
  count: number;
  /**
   * Size of agent VMs. Possible values include: 'Standard_A0', 'Standard_A1', 'Standard_A2',
   * 'Standard_A3', 'Standard_A4', 'Standard_A5', 'Standard_A6', 'Standard_A7', 'Standard_A8',
   * 'Standard_A9', 'Standard_A10', 'Standard_A11', 'Standard_D1', 'Standard_D2', 'Standard_D3',
   * 'Standard_D4', 'Standard_D11', 'Standard_D12', 'Standard_D13', 'Standard_D14',
   * 'Standard_D1_v2', 'Standard_D2_v2', 'Standard_D3_v2', 'Standard_D4_v2', 'Standard_D5_v2',
   * 'Standard_D11_v2', 'Standard_D12_v2', 'Standard_D13_v2', 'Standard_D14_v2', 'Standard_G1',
   * 'Standard_G2', 'Standard_G3', 'Standard_G4', 'Standard_G5', 'Standard_DS1', 'Standard_DS2',
   * 'Standard_DS3', 'Standard_DS4', 'Standard_DS11', 'Standard_DS12', 'Standard_DS13',
   * 'Standard_DS14', 'Standard_GS1', 'Standard_GS2', 'Standard_GS3', 'Standard_GS4',
   * 'Standard_GS5'
  */
  vmSize: string;
  /**
   * DNS prefix to be used to create the FQDN for the agent pool.
  */
  dnsPrefix: string;
  /**
   * FQDN for the agent pool.
  */
  readonly fqdn?: string;
}

/**
 * Profile for Windows VMs in the container service cluster.
*/
export interface ContainerServiceWindowsProfile {
  /**
   * The administrator username to use for Windows VMs.
  */
  adminUsername: string;
  /**
   * The administrator password to use for Windows VMs.
  */
  adminPassword: string;
}

/**
 * Contains information about SSH certificate public key data.
*/
export interface ContainerServiceSshPublicKey {
  /**
   * Certificate public key used to authenticate with VMs through SSH. The certificate must be in
   * PEM format with or without headers.
  */
  keyData: string;
}

/**
 * SSH configuration for Linux-based VMs running on Azure.
*/
export interface ContainerServiceSshConfiguration {
  /**
   * the list of SSH public keys used to authenticate with Linux-based VMs.
  */
  publicKeys: ContainerServiceSshPublicKey[];
}

/**
 * Profile for Linux VMs in the container service cluster.
*/
export interface ContainerServiceLinuxProfile {
  /**
   * The administrator username to use for Linux VMs.
  */
  adminUsername: string;
  /**
   * The ssh key configuration for Linux VMs.
  */
  ssh: ContainerServiceSshConfiguration;
}

/**
 * Profile for diagnostics on the container service VMs.
*/
export interface ContainerServiceVMDiagnostics {
  /**
   * Whether the VM diagnostic agent is provisioned on the VM.
  */
  enabled: boolean;
  /**
   * The URI of the storage account where diagnostics are stored.
  */
  readonly storageUri?: string;
}

export interface ContainerServiceDiagnosticsProfile {
  /**
   * Profile for the container service VM diagnostic agent.
  */
  vmDiagnostics: ContainerServiceVMDiagnostics;
}

/**
 * Container service.
*/
export interface ContainerService extends Resource {
  /**
   * the current deployment or provisioning state, which only appears in the response.
  */
  readonly provisioningState?: string;
  /**
   * Properties of the orchestrator.
  */
  orchestratorProfile?: ContainerServiceOrchestratorProfile;
  /**
   * Properties for custom clusters.
  */
  customProfile?: ContainerServiceCustomProfile;
  /**
   * Properties for cluster service principals.
  */
  servicePrincipalProfile?: ContainerServiceServicePrincipalProfile;
  /**
   * Properties of master agents.
  */
  masterProfile: ContainerServiceMasterProfile;
  /**
   * Properties of the agent pool.
  */
  agentPoolProfiles: ContainerServiceAgentPoolProfile[];
  /**
   * Properties of Windows VMs.
  */
  windowsProfile?: ContainerServiceWindowsProfile;
  /**
   * Properties of Linux VMs.
  */
  linuxProfile: ContainerServiceLinuxProfile;
  /**
   * Properties of the diagnostic agent.
  */
  diagnosticsProfile?: ContainerServiceDiagnosticsProfile;
}

/**
 * The List Compute Operation operation response.
*/
export interface ComputeOperationListResult extends Array<ComputeOperationValue> {
}

/**
 * The List Availability Set operation response.
*/
export interface AvailabilitySetListResult extends Array<AvailabilitySet> {
  /**
   * The URI to fetch the next page of AvailabilitySets. Call ListNext() with this URI to fetch the
   * next page of AvailabilitySets.
  */
  nextLink?: string;
}

/**
 * The List Virtual Machine operation response.
*/
export interface VirtualMachineSizeListResult extends Array<VirtualMachineSize> {
}

/**
 * The List Usages operation response.
*/
export interface ListUsagesResult extends Array<Usage> {
  /**
   * The URI to fetch the next page of compute resource usage information. Call ListNext() with
   * this to fetch the next page of compute resource usage information.
  */
  nextLink?: string;
}

/**
 * The List Virtual Machine operation response.
*/
export interface VirtualMachineListResult extends Array<VirtualMachine> {
  /**
   * The URI to fetch the next page of VMs. Call ListNext() with this URI to fetch the next page of
   * Virtual Machines.
  */
  nextLink?: string;
}

/**
 * The List Image operation response.
*/
export interface ImageListResult extends Array<Image> {
  /**
   * The uri to fetch the next page of Images. Call ListNext() with this to fetch the next page of
   * Images.
  */
  nextLink?: string;
}

/**
 * The List Virtual Machine operation response.
*/
export interface VirtualMachineScaleSetListResult extends Array<VirtualMachineScaleSet> {
  /**
   * The uri to fetch the next page of Virtual Machine Scale Sets. Call ListNext() with this to
   * fetch the next page of VMSS.
  */
  nextLink?: string;
}

/**
 * The List Virtual Machine operation response.
*/
export interface VirtualMachineScaleSetListWithLinkResult extends Array<VirtualMachineScaleSet> {
  /**
   * The uri to fetch the next page of Virtual Machine Scale Sets. Call ListNext() with this to
   * fetch the next page of Virtual Machine Scale Sets.
  */
  nextLink?: string;
}

/**
 * The Virtual Machine Scale Set List Skus operation response.
*/
export interface VirtualMachineScaleSetListSkusResult extends Array<VirtualMachineScaleSetSku> {
  /**
   * The uri to fetch the next page of Virtual Machine Scale Set Skus. Call ListNext() with this to
   * fetch the next page of VMSS Skus.
  */
  nextLink?: string;
}

/**
 * List of Virtual Machine Scale Set OS Upgrade History operation response.
*/
export interface VirtualMachineScaleSetListOSUpgradeHistory extends
Array<UpgradeOperationHistoricalStatusInfo> {
  /**
   * The uri to fetch the next page of OS Upgrade History. Call ListNext() with this to fetch the
   * next page of history of upgrades.
  */
  nextLink?: string;
}

/**
 * The List VM scale set extension operation response.
*/
export interface VirtualMachineScaleSetExtensionListResult extends
Array<VirtualMachineScaleSetExtension> {
  /**
   * The uri to fetch the next page of VM scale set extensions. Call ListNext() with this to fetch
   * the next page of VM scale set extensions.
  */
  nextLink?: string;
}

/**
 * The List Virtual Machine Scale Set VMs operation response.
*/
export interface VirtualMachineScaleSetVMListResult extends Array<VirtualMachineScaleSetVM> {
  /**
   * The uri to fetch the next page of Virtual Machine Scale Set VMs. Call ListNext() with this to
   * fetch the next page of VMSS VMs
  */
  nextLink?: string;
}

/**
 * The List Virtual Machine operation response.
*/
export interface RunCommandListResult extends Array<RunCommandDocumentBase> {
  /**
   * The uri to fetch the next page of run commands. Call ListNext() with this to fetch the next
   * page of run commands.
  */
  nextLink?: string;
}

/**
 * The Compute List Skus operation response.
*/
export interface ResourceSkusResult extends Array<ResourceSku> {
  /**
   * The uri to fetch the next page of Compute Skus. Call ListNext() with this to fetch the next
   * page of VMSS Skus.
  */
  nextLink?: string;
}

/**
 * The List Disks operation response.
*/
export interface DiskList extends Array<Disk> {
  /**
   * The uri to fetch the next page of disks. Call ListNext() with this to fetch the next page of
   * disks.
  */
  nextLink?: string;
}

/**
 * The List Snapshots operation response.
*/
export interface SnapshotList extends Array<Snapshot> {
  /**
   * The uri to fetch the next page of snapshots. Call ListNext() with this to fetch the next page
   * of snapshots.
  */
  nextLink?: string;
}

/**
 * The List Galleries operation response.
*/
export interface GalleryList extends Array<Gallery> {
  /**
   * The uri to fetch the next page of galleries. Call ListNext() with this to fetch the next page
   * of galleries.
  */
  nextLink?: string;
}

/**
 * The List Gallery Images operation response.
*/
export interface GalleryImageList extends Array<GalleryImage> {
  /**
   * The uri to fetch the next page of Image Definitions in the Shared Image Gallery. Call
   * ListNext() with this to fetch the next page of gallery Image Definitions.
  */
  nextLink?: string;
}

/**
 * The List Gallery Image version operation response.
*/
export interface GalleryImageVersionList extends Array<GalleryImageVersion> {
  /**
   * The uri to fetch the next page of gallery Image Versions. Call ListNext() with this to fetch
   * the next page of gallery Image Versions.
  */
  nextLink?: string;
}

/**
 * The response from the List Container Services operation.
*/
export interface ContainerServiceListResult extends Array<ContainerService> {
  /**
   * The URL to get the next set of container service results.
  */
  nextLink?: string;
}
