/*
 * Copyright (c) Microsoft Corporation. All rights reserved.
 * Licensed under the MIT License. See License.txt in the project root for
 * license information.
 *
 * Code generated by Microsoft (R) AutoRest Code Generator.
 * Changes may cause incorrect behavior and will be lost if the code is
 * regenerated.
 */

'use strict';

/**
 * Describes each OS upgrade on the Virtual Machine Scale Set.
 *
 */
class UpgradeOperationHistoricalStatusInfoProperties {
  /**
   * Create a UpgradeOperationHistoricalStatusInfoProperties.
   * @property {object} [runningStatus] Information about the overall status of
   * the upgrade operation.
   * @property {string} [runningStatus.code] Code indicating the current status
   * of the upgrade. Possible values include: 'RollingForward', 'Cancelled',
   * 'Completed', 'Faulted'
   * @property {date} [runningStatus.startTime] Start time of the upgrade.
   * @property {date} [runningStatus.endTime] End time of the upgrade.
   * @property {object} [progress] Counts of the VMs in each state.
   * @property {number} [progress.successfulInstanceCount] The number of
   * instances that have been successfully upgraded.
   * @property {number} [progress.failedInstanceCount] The number of instances
   * that have failed to be upgraded successfully.
   * @property {number} [progress.inProgressInstanceCount] The number of
   * instances that are currently being upgraded.
   * @property {number} [progress.pendingInstanceCount] The number of instances
   * that have not yet begun to be upgraded.
   * @property {object} [error] Error Details for this upgrade if there are
   * any.
   * @property {array} [error.details] The Api error details
   * @property {object} [error.innererror] The Api inner error
   * @property {string} [error.innererror.exceptiontype] The exception type.
   * @property {string} [error.innererror.errordetail] The internal error
   * message or exception dump.
   * @property {string} [error.code] The error code.
   * @property {string} [error.target] The target of the particular error.
   * @property {string} [error.message] The error message.
   * @property {string} [startedBy] Invoker of the Upgrade Operation. Possible
   * values include: 'Unknown', 'User', 'Platform'
   * @property {object} [targetImageReference] Image Reference details
   * @property {string} [targetImageReference.publisher] The image publisher.
   * @property {string} [targetImageReference.offer] Specifies the offer of the
   * platform image or marketplace image used to create the virtual machine.
   * @property {string} [targetImageReference.sku] The image SKU.
   * @property {string} [targetImageReference.version] Specifies the version of
   * the platform image or marketplace image used to create the virtual
   * machine. The allowed formats are Major.Minor.Build or 'latest'. Major,
   * Minor, and Build are decimal numbers. Specify 'latest' to use the latest
   * version of an image available at deploy time. Even if you use 'latest',
   * the VM image will not automatically update after deploy time even if a new
   * version becomes available.
   * @property {object} [rollbackInfo] Information about OS rollback if
   * performed
   * @property {number} [rollbackInfo.successfullyRolledbackInstanceCount] The
   * number of instances which have been successfully rolled back.
   * @property {number} [rollbackInfo.failedRolledbackInstanceCount] The number
   * of instances which failed to rollback.
   * @property {object} [rollbackInfo.rollbackError] Error details if OS
   * rollback failed.
   * @property {array} [rollbackInfo.rollbackError.details] The Api error
   * details
   * @property {object} [rollbackInfo.rollbackError.innererror] The Api inner
   * error
   * @property {string} [rollbackInfo.rollbackError.innererror.exceptiontype]
   * The exception type.
   * @property {string} [rollbackInfo.rollbackError.innererror.errordetail] The
   * internal error message or exception dump.
   * @property {string} [rollbackInfo.rollbackError.code] The error code.
   * @property {string} [rollbackInfo.rollbackError.target] The target of the
   * particular error.
   * @property {string} [rollbackInfo.rollbackError.message] The error message.
   */
  constructor() {
  }

  /**
   * Defines the metadata of UpgradeOperationHistoricalStatusInfoProperties
   *
   * @returns {object} metadata of UpgradeOperationHistoricalStatusInfoProperties
   *
   */
  mapper() {
    return {
      required: false,
      serializedName: 'UpgradeOperationHistoricalStatusInfoProperties',
      type: {
        name: 'Composite',
        className: 'UpgradeOperationHistoricalStatusInfoProperties',
        modelProperties: {
          runningStatus: {
            required: false,
            readOnly: true,
            serializedName: 'runningStatus',
            type: {
              name: 'Composite',
              className: 'UpgradeOperationHistoryStatus'
            }
          },
          progress: {
            required: false,
            readOnly: true,
            serializedName: 'progress',
            type: {
              name: 'Composite',
              className: 'RollingUpgradeProgressInfo'
            }
          },
          error: {
            required: false,
            readOnly: true,
            serializedName: 'error',
            type: {
              name: 'Composite',
              className: 'ApiError'
            }
          },
          startedBy: {
            required: false,
            readOnly: true,
            serializedName: 'startedBy',
            type: {
              name: 'Enum',
              allowedValues: [ 'Unknown', 'User', 'Platform' ]
            }
          },
          targetImageReference: {
            required: false,
            readOnly: true,
            serializedName: 'targetImageReference',
            type: {
              name: 'Composite',
              className: 'ImageReference'
            }
          },
          rollbackInfo: {
            required: false,
            readOnly: true,
            serializedName: 'rollbackInfo',
            type: {
              name: 'Composite',
              className: 'RollbackStatusInfo'
            }
          }
        }
      }
    };
  }
}

module.exports = UpgradeOperationHistoricalStatusInfoProperties;
