/*
 * Copyright (c) Microsoft Corporation. All rights reserved.
 * Licensed under the MIT License. See License.txt in the project root for
 * license information.
 *
 * Code generated by Microsoft (R) AutoRest Code Generator.
 * Changes may cause incorrect behavior and will be lost if the code is
 * regenerated.
 */

'use strict';

const models = require('./index');

/**
 * Describes a Virtual Machine Scale Set Extension.
 *
 * @extends models['SubResourceReadOnly']
 */
class VirtualMachineScaleSetExtension extends models['SubResourceReadOnly'] {
  /**
   * Create a VirtualMachineScaleSetExtension.
   * @property {string} [name] The name of the extension.
   * @property {string} [forceUpdateTag] If a value is provided and is
   * different from the previous value, the extension handler will be forced to
   * update even if the extension configuration has not changed.
   * @property {string} [publisher] The name of the extension handler
   * publisher.
   * @property {string} [type] Specifies the type of the extension; an example
   * is "CustomScriptExtension".
   * @property {string} [typeHandlerVersion] Specifies the version of the
   * script handler.
   * @property {boolean} [autoUpgradeMinorVersion] Indicates whether the
   * extension should use a newer minor version if one is available at
   * deployment time. Once deployed, however, the extension will not upgrade
   * minor versions unless redeployed, even with this property set to true.
   * @property {object} [settings] Json formatted public settings for the
   * extension.
   * @property {object} [protectedSettings] The extension can contain either
   * protectedSettings or protectedSettingsFromKeyVault or no protected
   * settings at all.
   * @property {string} [provisioningState] The provisioning state, which only
   * appears in the response.
   * @property {array} [provisionAfterExtensions] Collection of extension names
   * after which this extension needs to be provisioned.
   */
  constructor() {
    super();
  }

  /**
   * Defines the metadata of VirtualMachineScaleSetExtension
   *
   * @returns {object} metadata of VirtualMachineScaleSetExtension
   *
   */
  mapper() {
    return {
      required: false,
      serializedName: 'VirtualMachineScaleSetExtension',
      type: {
        name: 'Composite',
        className: 'VirtualMachineScaleSetExtension',
        modelProperties: {
          id: {
            required: false,
            readOnly: true,
            serializedName: 'id',
            type: {
              name: 'String'
            }
          },
          name: {
            required: false,
            serializedName: 'name',
            type: {
              name: 'String'
            }
          },
          forceUpdateTag: {
            required: false,
            serializedName: 'properties.forceUpdateTag',
            type: {
              name: 'String'
            }
          },
          publisher: {
            required: false,
            serializedName: 'properties.publisher',
            type: {
              name: 'String'
            }
          },
          type: {
            required: false,
            serializedName: 'properties.type',
            type: {
              name: 'String'
            }
          },
          typeHandlerVersion: {
            required: false,
            serializedName: 'properties.typeHandlerVersion',
            type: {
              name: 'String'
            }
          },
          autoUpgradeMinorVersion: {
            required: false,
            serializedName: 'properties.autoUpgradeMinorVersion',
            type: {
              name: 'Boolean'
            }
          },
          settings: {
            required: false,
            serializedName: 'properties.settings',
            type: {
              name: 'Object'
            }
          },
          protectedSettings: {
            required: false,
            serializedName: 'properties.protectedSettings',
            type: {
              name: 'Object'
            }
          },
          provisioningState: {
            required: false,
            readOnly: true,
            serializedName: 'properties.provisioningState',
            type: {
              name: 'String'
            }
          },
          provisionAfterExtensions: {
            required: false,
            serializedName: 'properties.provisionAfterExtensions',
            type: {
              name: 'Sequence',
              element: {
                  required: false,
                  serializedName: 'StringElementType',
                  type: {
                    name: 'String'
                  }
              }
            }
          }
        }
      }
    };
  }
}

module.exports = VirtualMachineScaleSetExtension;
