/*
 * Copyright (c) Microsoft Corporation. All rights reserved.
 * Licensed under the MIT License. See License.txt in the project root for
 * license information.
 *
 * Code generated by Microsoft (R) AutoRest Code Generator.
 * Changes may cause incorrect behavior and will be lost if the code is
 * regenerated.
 */

'use strict';

/**
 * Describes a virtual machine scale set storage profile.
 *
 */
class VirtualMachineScaleSetStorageProfile {
  /**
   * Create a VirtualMachineScaleSetStorageProfile.
   * @property {object} [imageReference] Specifies information about the image
   * to use. You can specify information about platform images, marketplace
   * images, or virtual machine images. This element is required when you want
   * to use a platform image, marketplace image, or virtual machine image, but
   * is not used in other creation operations.
   * @property {string} [imageReference.publisher] The image publisher.
   * @property {string} [imageReference.offer] Specifies the offer of the
   * platform image or marketplace image used to create the virtual machine.
   * @property {string} [imageReference.sku] The image SKU.
   * @property {string} [imageReference.version] Specifies the version of the
   * platform image or marketplace image used to create the virtual machine.
   * The allowed formats are Major.Minor.Build or 'latest'. Major, Minor, and
   * Build are decimal numbers. Specify 'latest' to use the latest version of
   * an image available at deploy time. Even if you use 'latest', the VM image
   * will not automatically update after deploy time even if a new version
   * becomes available.
   * @property {object} [osDisk] Specifies information about the operating
   * system disk used by the virtual machines in the scale set. <br><br> For
   * more information about disks, see [About disks and VHDs for Azure virtual
   * machines](https://docs.microsoft.com/azure/virtual-machines/virtual-machines-windows-about-disks-vhds?toc=%2fazure%2fvirtual-machines%2fwindows%2ftoc.json).
   * @property {string} [osDisk.name] The disk name.
   * @property {string} [osDisk.caching] Specifies the caching requirements.
   * <br><br> Possible values are: <br><br> **None** <br><br> **ReadOnly**
   * <br><br> **ReadWrite** <br><br> Default: **None for Standard storage.
   * ReadOnly for Premium storage**. Possible values include: 'None',
   * 'ReadOnly', 'ReadWrite'
   * @property {boolean} [osDisk.writeAcceleratorEnabled] Specifies whether
   * writeAccelerator should be enabled or disabled on the disk.
   * @property {string} [osDisk.createOption] Specifies how the virtual
   * machines in the scale set should be created.<br><br> The only allowed
   * value is: **FromImage** \u2013 This value is used when you are using an
   * image to create the virtual machine. If you are using a platform image,
   * you also use the imageReference element described above. If you are using
   * a marketplace image, you  also use the plan element previously described.
   * Possible values include: 'FromImage', 'Empty', 'Attach'
   * @property {object} [osDisk.diffDiskSettings] Specifies the ephemeral disk
   * Settings for the operating system disk used by the virtual machine scale
   * set.
   * @property {string} [osDisk.diffDiskSettings.option] Specifies the
   * ephemeral disk settings for operating system disk. Possible values
   * include: 'Local'
   * @property {number} [osDisk.diskSizeGB] Specifies the size of the operating
   * system disk in gigabytes. This element can be used to overwrite the size
   * of the disk in a virtual machine image. <br><br> This value cannot be
   * larger than 1023 GB
   * @property {string} [osDisk.osType] This property allows you to specify the
   * type of the OS that is included in the disk if creating a VM from
   * user-image or a specialized VHD. <br><br> Possible values are: <br><br>
   * **Windows** <br><br> **Linux**. Possible values include: 'Windows',
   * 'Linux'
   * @property {object} [osDisk.image] Specifies information about the
   * unmanaged user image to base the scale set on.
   * @property {string} [osDisk.image.uri] Specifies the virtual hard disk's
   * uri.
   * @property {array} [osDisk.vhdContainers] Specifies the container urls that
   * are used to store operating system disks for the scale set.
   * @property {object} [osDisk.managedDisk] The managed disk parameters.
   * @property {string} [osDisk.managedDisk.storageAccountType] Specifies the
   * storage account type for the managed disk. NOTE: UltraSSD_LRS can only be
   * used with data disks, it cannot be used with OS Disk. Possible values
   * include: 'Standard_LRS', 'Premium_LRS', 'StandardSSD_LRS', 'UltraSSD_LRS'
   * @property {array} [dataDisks] Specifies the parameters that are used to
   * add data disks to the virtual machines in the scale set. <br><br> For more
   * information about disks, see [About disks and VHDs for Azure virtual
   * machines](https://docs.microsoft.com/azure/virtual-machines/virtual-machines-windows-about-disks-vhds?toc=%2fazure%2fvirtual-machines%2fwindows%2ftoc.json).
   */
  constructor() {
  }

  /**
   * Defines the metadata of VirtualMachineScaleSetStorageProfile
   *
   * @returns {object} metadata of VirtualMachineScaleSetStorageProfile
   *
   */
  mapper() {
    return {
      required: false,
      serializedName: 'VirtualMachineScaleSetStorageProfile',
      type: {
        name: 'Composite',
        className: 'VirtualMachineScaleSetStorageProfile',
        modelProperties: {
          imageReference: {
            required: false,
            serializedName: 'imageReference',
            type: {
              name: 'Composite',
              className: 'ImageReference'
            }
          },
          osDisk: {
            required: false,
            serializedName: 'osDisk',
            type: {
              name: 'Composite',
              className: 'VirtualMachineScaleSetOSDisk'
            }
          },
          dataDisks: {
            required: false,
            serializedName: 'dataDisks',
            type: {
              name: 'Sequence',
              element: {
                  required: false,
                  serializedName: 'VirtualMachineScaleSetDataDiskElementType',
                  type: {
                    name: 'Composite',
                    className: 'VirtualMachineScaleSetDataDisk'
                  }
              }
            }
          }
        }
      }
    };
  }
}

module.exports = VirtualMachineScaleSetStorageProfile;
