/*
 * Copyright (c) Microsoft Corporation. All rights reserved.
 * Licensed under the MIT License. See License.txt in the project root for
 * license information.
 *
 * Code generated by Microsoft (R) AutoRest Code Generator.
 * Changes may cause incorrect behavior and will be lost if the code is
 * regenerated.
 */

'use strict';

const models = require('./index');

/**
 * Describes a virtual machine scale set network profile's IP configuration.
 *
 * @extends models['SubResource']
 */
class VirtualMachineScaleSetUpdateIPConfiguration extends models['SubResource'] {
  /**
   * Create a VirtualMachineScaleSetUpdateIPConfiguration.
   * @property {string} [name] The IP configuration name.
   * @property {object} [subnet] The subnet.
   * @property {string} [subnet.id] The ARM resource id in the form of
   * /subscriptions/{SubscriptionId}/resourceGroups/{ResourceGroupName}/...
   * @property {boolean} [primary] Specifies the primary IP Configuration in
   * case the network interface has more than one IP Configuration.
   * @property {object} [publicIPAddressConfiguration] The
   * publicIPAddressConfiguration.
   * @property {string} [publicIPAddressConfiguration.name] The publicIP
   * address configuration name.
   * @property {number} [publicIPAddressConfiguration.idleTimeoutInMinutes] The
   * idle timeout of the public IP address.
   * @property {object} [publicIPAddressConfiguration.dnsSettings] The dns
   * settings to be applied on the publicIP addresses .
   * @property {string}
   * [publicIPAddressConfiguration.dnsSettings.domainNameLabel] The Domain name
   * label.The concatenation of the domain name label and vm index will be the
   * domain name labels of the PublicIPAddress resources that will be created
   * @property {string} [privateIPAddressVersion] Available from Api-Version
   * 2017-03-30 onwards, it represents whether the specific ipconfiguration is
   * IPv4 or IPv6. Default is taken as IPv4.  Possible values are: 'IPv4' and
   * 'IPv6'. Possible values include: 'IPv4', 'IPv6'
   * @property {array} [applicationGatewayBackendAddressPools] The application
   * gateway backend address pools.
   * @property {array} [applicationSecurityGroups] Specifies an array of
   * references to application security group.
   * @property {array} [loadBalancerBackendAddressPools] The load balancer
   * backend address pools.
   * @property {array} [loadBalancerInboundNatPools] The load balancer inbound
   * nat pools.
   */
  constructor() {
    super();
  }

  /**
   * Defines the metadata of VirtualMachineScaleSetUpdateIPConfiguration
   *
   * @returns {object} metadata of VirtualMachineScaleSetUpdateIPConfiguration
   *
   */
  mapper() {
    return {
      required: false,
      serializedName: 'VirtualMachineScaleSetUpdateIPConfiguration',
      type: {
        name: 'Composite',
        className: 'VirtualMachineScaleSetUpdateIPConfiguration',
        modelProperties: {
          id: {
            required: false,
            serializedName: 'id',
            type: {
              name: 'String'
            }
          },
          name: {
            required: false,
            serializedName: 'name',
            type: {
              name: 'String'
            }
          },
          subnet: {
            required: false,
            serializedName: 'properties.subnet',
            type: {
              name: 'Composite',
              className: 'ApiEntityReference'
            }
          },
          primary: {
            required: false,
            serializedName: 'properties.primary',
            type: {
              name: 'Boolean'
            }
          },
          publicIPAddressConfiguration: {
            required: false,
            serializedName: 'properties.publicIPAddressConfiguration',
            type: {
              name: 'Composite',
              className: 'VirtualMachineScaleSetUpdatePublicIPAddressConfiguration'
            }
          },
          privateIPAddressVersion: {
            required: false,
            serializedName: 'properties.privateIPAddressVersion',
            type: {
              name: 'String'
            }
          },
          applicationGatewayBackendAddressPools: {
            required: false,
            serializedName: 'properties.applicationGatewayBackendAddressPools',
            type: {
              name: 'Sequence',
              element: {
                  required: false,
                  serializedName: 'SubResourceElementType',
                  type: {
                    name: 'Composite',
                    className: 'SubResource'
                  }
              }
            }
          },
          applicationSecurityGroups: {
            required: false,
            serializedName: 'properties.applicationSecurityGroups',
            type: {
              name: 'Sequence',
              element: {
                  required: false,
                  serializedName: 'SubResourceElementType',
                  type: {
                    name: 'Composite',
                    className: 'SubResource'
                  }
              }
            }
          },
          loadBalancerBackendAddressPools: {
            required: false,
            serializedName: 'properties.loadBalancerBackendAddressPools',
            type: {
              name: 'Sequence',
              element: {
                  required: false,
                  serializedName: 'SubResourceElementType',
                  type: {
                    name: 'Composite',
                    className: 'SubResource'
                  }
              }
            }
          },
          loadBalancerInboundNatPools: {
            required: false,
            serializedName: 'properties.loadBalancerInboundNatPools',
            type: {
              name: 'Sequence',
              element: {
                  required: false,
                  serializedName: 'SubResourceElementType',
                  type: {
                    name: 'Composite',
                    className: 'SubResource'
                  }
              }
            }
          }
        }
      }
    };
  }
}

module.exports = VirtualMachineScaleSetUpdateIPConfiguration;
